<?php
/**
 * 后台管理员数据迁移
 * User: lzs
 * Date: 2020/10/28
 * Time: 11:31
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Models\Administrator;
use App\Models\Role;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;
use Illuminate\Support\Facades\Hash;

class AdminUsers
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 后台管理员数据迁移
        $data = self::users($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('admin_users', $data['users'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取后台管理员数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function users(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('admin')->where('isDelete', '0');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $users = $baseQuery->select(['id', 'groupId', 'name', 'email', 'mobile', 'password', 'is_notify', 'status', 'lockStatus', 'salt'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        $time = date('Y-m-d H:i:s');
        $administrators = [];
        foreach ($users  as $user){
            if ($user->groupId == 1){
                $administrators[] = $user->id;
            }
            $data[] = [
                'id' => $user->id,
                'name' => $user->name,
                'phone' => $user->mobile ?? '',
                'email' => $user->email ?? '',
                'password' => Hash::make($user->password),
                'is_notify' => $user->is_notify == 0 ? Administrator::NOTIFY_NO : Administrator::NOTIFY_YES,
                'is_locked' => $user->lockStatus == 0 ? Administrator::LOCKED_NO : Administrator::LOCKED_YES,
                'enable' => $user->status == 0 ? Administrator::ENABLE_NO : Administrator::ENABLE_YES,
                'is_md5_pwd' => Administrator::IS_MD5_PWD_YES,
                'prev_sys_salt' => $user->salt,
                'locked_at' => null,
                'deleted_at' => null,
                'created_at' => $time,
                'updated_at' => $time,
            ];
        }

        // 超级管理员设置
        if ($administrators){
            $role = Role::find(1);
            $role->administrators()->sync($administrators);
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'users' => $data
        ];
    }

}