<?php
/**
 * 文章类别数据迁移
 * User: lzs
 * Date: 2020/11/27
 * Time: 9:07
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Models\ArticleCategory;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class ArticleCategories
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 文章类别数据迁移
        $data = self::categories($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('article_categories', $data['categories'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取文章类别数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function categories(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('news_class');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $categories = $baseQuery->select(['id', 'name', 'status', 'enName', 'type'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        $time = date('Y-m-d H:i:s');
        $classMap = [
            'news' => ArticleCategory::CATEGORY_NEWS,
            'notice' => ArticleCategory::CATEGORY_ANNOUNCEMENT,
        ];
        $newsIdentityMap = [
            'tnews' => ArticleCategory::NEWS_IDENTITY_TM_IPR,
            'snews' => ArticleCategory::NEWS_IDENTITY_COMPANY_SERVICE,
        ];
        $announcementIdentityMap = [
            'dnotice' => ArticleCategory::ANNOUNCEMENT_IDENTITY_DOMAIN_REG,
            'tnotice' => ArticleCategory::ANNOUNCEMENT_IDENTITY_TM_IPR,
        ];
        foreach ($categories  as $category){
            $class = isset($classMap[$category->type]) ? $classMap[$category->type] : ArticleCategory::CATEGORY_NEWS;
            $identity = $category->enName;
            if ($class == ArticleCategory::CATEGORY_NEWS){
                $identity = isset($newsIdentityMap[$category->enName]) ? $newsIdentityMap[$category->enName] : $category->enName;
            }elseif ($class == ArticleCategory::CATEGORY_ANNOUNCEMENT){
                $identity = isset($announcementIdentityMap[$category->enName]) ? $announcementIdentityMap[$category->enName] : $category->enName;
            }

            $data[] = [
                'id' => $category->id,
                'name' => $category->name,
                'class' => $class,
                'identity' => $identity,
                'enable' => $category->status == 1 ? ArticleCategory::ENABLE_YES : ArticleCategory::ENABLE_NO,
                'created_at' => $time,
                'updated_at' => $time,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'categories' => $data
        ];
    }
}