<?php
/**
 * 文章（资讯和公告）数据迁移
 * User: lzs
 * Date: 2020/11/26
 * Time: 17:44
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Models\Article;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class Articles
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 文章数据迁移
        $data = self::articles($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('articles', $data['articles'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取文章数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function articles(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('news');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $articles = $baseQuery->select(['id', 'sortID', 'title', 'descript', 'content', 'createTime', 'type', 'class_tag', 'author', 'view', 'source', 'keyword', 'enable'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        $time = date('Y-m-d H:i:s');
        $categories = $connection->table('news_class')->select(['id', 'enName', 'type'])->get();
        foreach ($articles  as $article){
            $category = $categories->where('type', $article->type)->where('enName', $article->class_tag)->first();
            if (!$category){
                if (in_array($article->type, ['news', 'notice'])){
                    $category = $categories->where('type', $article->type)->first();
                }else{
                    $category = $categories->first();
                }
            }
            $categoryId = $category ? $category->id : 0;
            $data[] = [
                'id' => $article->id,
                'category_id' => $categoryId,
                'title' => $article->title,
                'keywords' => $article->keyword ?: '',
                'description' => $article->descript ?: '',
                'author' => $article->author ?: '',
                'source' => $article->source ?: '',
                'views' => intval($article->view),
                'content' => $article->content,
                'order' => $article->sortID,
                'published_at' => $article->createTime != '0000-00-00 00:00:00' ? $article->createTime : $time,
                'created_at' => $time,
                'updated_at' => $time,
                'enable' => $article->enable == 1 ? Article::ENABLE_YES : Article::ENABLE_NO,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'articles' => $data
        ];
    }
}
