<?php
/**
 * 附件数据迁移
 * User: lzs
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Models\Attachment;
use App\Models\TmReg;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class Attachments
{
    public static function handle(ConnectionInterface $connection)
    {
        $attachments = collect([]);

        // config_banner 图片数据迁移
        $attachments = $attachments->merge(self::banner($connection));

        // gw_examples 图片数据迁移
        $attachments = $attachments->merge(self::gwExamples($connection));

        // users_auth 图片数据迁移
        $attachments = $attachments->merge(self::usersAuth($connection));

        // enterprise_email 图片数据迁移
        $attachments = $attachments->merge(self::enterpriseEmail($connection));

        // navigation 图片数据迁移
        $attachments = $attachments->merge(self::navigation($connection));

        // config 图片数据迁移
        $attachments = $attachments->merge(self::config($connection));

        // tm_regs 图片数据迁移
        $attachments = $attachments->merge(self::tmReg($connection));

        // tm_applicants 图片数据迁移
        $attachments = $attachments->merge(self::tmApplicant($connection));

        // tm_trade_holders 图片数据迁移
        $attachments = $attachments->merge(self::tmTradeHolder($connection));

        // domain_templates 图片数据迁移
        $attachments = $attachments->merge(self::domainTemplate($connection));

        // tm_notarizations 图片数据迁移
        $attachments = $attachments->merge(self::tmNotarization($connection));

        // path去重
        $attachmentPaths = [];
        foreach ($attachments as $key => $attachment){
            if(in_array($attachment['path'], $attachmentPaths)){
                unset($attachments[$key]);
                continue;
            }
            $attachmentPaths[] = $attachment['path'];
        }

        // 处理数据
        $attachments->transform(function ($attachment, $key){
            $pathInfo = pathinfo($attachment['path']);
            return [
                'name' => isset($pathInfo['basename']) ? $pathInfo['basename'] : '',
                'disk' => Attachment::DISK_MIGRATION,
                'user_id' => isset($attachment['user_id']) ? $attachment['user_id'] : 0,
                'type' => isset($attachment['type']) ? $attachment['type'] : Attachment::TYPE_NOMAL,
                'path' => $attachment['path'],
                'mime' => '',
                'extension' => isset($pathInfo['extension']) ? $pathInfo['extension'] : '',
                'size' => 0,
                'source' => Attachment::SOURCE_MIGRATION,
                'ep_id' => isset($attachment['ep_id']) ? $attachment['ep_id'] : 0,
                'fixed' => 1,
            ];
        });

        // 生成 SQL 语句
        MigrationService::insert('attachments', $attachments->toArray(), 2);

        return [
            'is_finished' => true,
        ];
    }

    /**
     * Banner 图相关的附件数据
     * @param ConnectionInterface $connection
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function banner(ConnectionInterface $connection)
    {
        $banners = $connection->table('config_banner')
            ->where('status', '<>', -1)
            ->select(['pic', 'picm'])
            ->get();

        $attachments = [];
        foreach ($banners as $banner){
            if ($banner->pic){
                $attachments[] = [
                    'path' => $banner->pic
                ];
            }
            if ($banner->picm){
                $attachments[] = [
                    'path' => $banner->picm
                ];
            }
        }

        return $attachments;
    }

    /**
     * 官微案例 相关的附件数据
     * @param ConnectionInterface $connection
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function gwExamples(ConnectionInterface $connection)
    {
        $examples = $connection->table('gw_examples')
            ->select(['img'])
            ->get();

        $attachments = [];
        foreach ($examples as $example){
            if ($example->img){
                $attachments[] = [
                    'path' => $example->img
                ];
            }
        }

        return $attachments;
    }



    /**
     * 用户认证相关的附件数据
     * @param ConnectionInterface $connection
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function usersAuth(ConnectionInterface $connection)
    {
        $auths = $connection->table('users_auth')
            ->where('isDelete', '0')
            ->where('status', 20)
            ->select(['authPic1', 'authPic2'])
            ->get();

        $attachments = [];
        foreach ($auths as $auth){
            if ($auth->authPic1){
                $attachments[] = [
                    'path' => $auth->authPic1,
                    'type' => Attachment::TYPE_USER_AUTH,
                ];
            }
            if ($auth->authPic2){
                $attachments[] = [
                    'path' => $auth->authPic2,
                    'type' => Attachment::TYPE_USER_AUTH,
                ];
            }
        }

        return $attachments;
    }

    /**
     * 企业邮箱相关的附件数据
     * @param ConnectionInterface $connection
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function enterpriseEmail(ConnectionInterface $connection)
    {
        $auths = $connection->table('enterprise_email')
            ->select(['logo_path', 'bgimg_path'])
            ->get();

        $attachments = [];
        foreach ($auths as $auth){
            if ($auth->logo_path){
                $attachments[] = [
                    'path' => $auth->logo_path,
                    'type' => Attachment::ETP_EMAIL_LOGO,
                    'ep_id' => -1,
                ];
            }
            if ($auth->bgimg_path){
                $attachments[] = [
                    'path' => $auth->bgimg_path,
                    'type' => Attachment::ETP_EMAIL_BGI,
                    'ep_id' => -1,
                ];
            }
        }

        return $attachments;
    }

    /**
     * 导航相关的附件数据
     * @param ConnectionInterface $connection
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function navigation(ConnectionInterface $connection)
    {
        $navs = $connection->table('navigation')
            ->select(['pic'])
            ->get();

        $attachments = [];
        foreach ($navs as $nav){
            if ($nav->pic){
                $attachments[] = [
                    'path' => $nav->pic
                ];
            }
        }

        return $attachments;
    }

    /**
     * 配置相关的附件数据
     * @param ConnectionInterface $connection
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function config(ConnectionInterface $connection)
    {
        $configs = $connection->table('config')
            ->whereIn('key',['basic','product'])
            ->get();

        $attachments = [];
        foreach ($configs as $config){
            $deConfig = json_decode(base64_decode($config->value),true);
            if (isset($deConfig['userLogo'])){
                $attachments[] = [
                    'path' => $deConfig['userLogo']
                ];
            }
            if (isset($deConfig['mobileLogo'])){
                $attachments[] = [
                    'path' => $deConfig['mobileLogo']
                ];
            }
            if (isset($deConfig['wxLogo'])){
                $attachments[] = [
                    'path' => $deConfig['wxLogo']
                ];
            }
            if (isset($deConfig['commissionBg'])){
                $attachments[] = [
                    'path' => $deConfig['commissionBg']
                ];
            }
        }

        return $attachments;
    }

    /**
     * 商标注册相关的附件数据
     * @param ConnectionInterface $connection
     * @return array
     * @brand ePower
     * @author jcq
     */
    private static function tmReg(ConnectionInterface $connection)
    {
        $businessses = $connection->table('tm_orders')
            ->whereIn('status',[TmReg::unverified_status,TmReg::failed_status,TmReg::to_submit_status,TmReg::unconfirmed_status])
            ->select(['delegationfile', 'image1file', 'userid'])
            ->get();

        $attachments = [];
        foreach ($businessses as $businesss){
            if ($businesss->delegationfile){
                $attachments[] = [
                    'path' => $businesss->delegationfile,
                    'type' => Attachment::TM_REGISTRATION_DELEGATION_FILE,
                    'user_id' => $businesss->userid,
                    'ep_id' => -1,
                ];
            }
            if ($businesss->image1file){
                $attachments[] = [
                    'path' => $businesss->image1file,
                    'type' => Attachment::TM_REGISTRATION_IMAGE_FILE,
                    'user_id' => $businesss->userid,
                    'ep_id' => -1,
                ];
            }
        }

        return $attachments;
    }

    /**
     * 商标申请人相关的附件数据
     * @param ConnectionInterface $connection
     * @return array
     * @brand ePower
     * @author jcq
     */
    private static function tmApplicant(ConnectionInterface $connection)
    {
        $businessses = $connection->table('tm_applyer')
            ->select(['cerificatefile', 'cerificatefile2', 'businessfile', 'businessfileen', 'userid'])
            ->get();

        $attachments = [];
        foreach ($businessses as $businesss){
            if ($businesss->cerificatefile){
                $attachments[] = [
                    'path' => $businesss->cerificatefile,
                    'type' => Attachment::TM_APPPLICANT_ID_FRONT_FILE,
                    'user_id' => $businesss->userid,
                    'ep_id' => -1,
                ];
            }
            if ($businesss->cerificatefile2){
                $attachments[] = [
                    'path' => $businesss->cerificatefile2,
                    'type' => Attachment::TM_APPPLICANT_ID_BACK_FILE,
                    'user_id' => $businesss->userid,
                    'ep_id' => -1,
                ];
            }
            if ($businesss->businessfile){
                $attachments[] = [
                    'path' => $businesss->businessfile,
                    'type' => Attachment::TM_APPPLICANT_BUSINESS_FILE,
                    'user_id' => $businesss->userid,
                    'ep_id' => -1,
                ];
            }
            if ($businesss->businessfileen){
                $attachments[] = [
                    'path' => $businesss->businessfileen,
                    'type' => Attachment::TM_APPPLICANT_BUSINESS_EN_FILE,
                    'user_id' => $businesss->userid,
                    'ep_id' => -1,
                ];
            }
        }

        return $attachments;
    }

    /**
     * 商标交易持有人的附件数据
     * @param ConnectionInterface $connection
     * @return array
     * @brand ePower
     * @author jcq
     */
    private static function tmTradeHolder(ConnectionInterface $connection)
    {
        $businessses = $connection->table('tmjiaoyiapplyer')
            ->select(['img', 'userid'])
            ->get();

        $attachments = [];
        foreach ($businessses as $businesss){
            if ($businesss->img){
                $attachments[] = [
                    'path' => $businesss->img,
                    'type' => Attachment::TM_TRADE_HOLDER_FILE,
                    'user_id' => $businesss->userid,
                    'ep_id' => -1,
                ];
            }
        }

        return $attachments;
    }

    /**
     * 域名模板的附件数据
     * @param ConnectionInterface $connection
     * @return array
     * @brand ePower
     * @author jcq
     */
    private static function domainTemplate(ConnectionInterface $connection)
    {
        $businessses = $connection->table('contactors')
            ->select(['cert_file_org', 'cert_file_personal', 'user_id'])
            ->get();

        $attachments = [];
        foreach ($businessses as $businesss){
            if ($businesss->cert_file_org && !$businesss->cert_file_personal){
                $attachments[] = [
                    'path' => $businesss->cert_file_org,
                    'type' => Attachment::DOMAIN_TEMPLATE_BUSINESS_FILE,
                    'user_id' => $businesss->user_id,
                    'ep_id' => -1,
                ];
            }

            if ($businesss->cert_file_personal){
                $attachments[] = [
                    'path' => $businesss->cert_file_personal,
                    'type' => Attachment::DOMAIN_TEMPLATE_ORG_FILE,
                    'user_id' => $businesss->user_id,
                    'ep_id' => -1,
                ];
            }
        }

        return $attachments;
    }

    /**
     * 商标公证的附件数据
     * @param ConnectionInterface $connection
     * @return array
     * @brand ePower
     * @author jcq
     */
    private static function tmNotarization(ConnectionInterface $connection)
    {
        $businessses = $connection->table('notarizations')
            ->select(['assignor_detail', 'assignee_detail', 'tm_img', 'tm_zrzm_img', 'gdhjy_img', 'user_id'])
            ->get();

        $attachments = [];
        foreach ($businessses as $businesss){
            $assignor_detail = json_decode($businesss->assignor_detail,true); # 转让人信息
            if($assignor_detail['person_portraint_img']){
                $attachments[] = [
                    'path' => $assignor_detail['person_portraint_img'],
                    'type' => Attachment::TMN_ZR_ID_FRONT_FILE,
                    'user_id' => $businesss->user_id,
                    'ep_id' => -1,
                ];
            }
            if($assignor_detail['person_emblem_img']){
                $attachments[] = [
                    'path' => $assignor_detail['person_emblem_img'],
                    'type' => Attachment::TMN_ZR_ID_BACK_FILE,
                    'user_id' => $businesss->user_id,
                    'ep_id' => -1,
                ];
            }
            if($assignor_detail['company_business_license_img']){
                $attachments[] = [
                    'path' => $assignor_detail['company_business_license_img'],
                    'type' => Attachment::TMN_ZR_BUSINESS_FILE,
                    'user_id' => $businesss->user_id,
                    'ep_id' => -1,
                ];
            }

            $assignee_detail = json_decode($businesss->assignee_detail,true); # 受让人信息
            if($assignee_detail['person_portraint_img']){
                $attachments[] = [
                    'path' => $assignee_detail['person_portraint_img'],
                    'type' => Attachment::TMN_SR_ID_FRONT_FILE,
                    'user_id' => $businesss->user_id,
                    'ep_id' => -1,
                ];
            }
            if($assignee_detail['person_emblem_img']){
                $attachments[] = [
                    'path' => $assignee_detail['person_emblem_img'],
                    'type' => Attachment::TMN_SR_ID_BACK_FILE,
                    'user_id' => $businesss->user_id,
                    'ep_id' => -1,
                ];
            }
            if($assignee_detail['company_business_license_img']){
                $attachments[] = [
                    'path' => $assignee_detail['company_business_license_img'],
                    'type' => Attachment::TMN_SR_BUSINESS_FILE,
                    'user_id' => $businesss->user_id,
                    'ep_id' => -1,
                ];
            }

            if ($businesss->tm_img){
                $attachments[] = [
                    'path' => $businesss->tm_img,
                    'type' => Attachment::TMN_REG_FILE,
                    'user_id' => $businesss->user_id,
                    'ep_id' => -1,
                ];
            }
            if ($businesss->tm_zrzm_img){
                $attachments[] = [
                    'path' => $businesss->tm_zrzm_img,
                    'type' => Attachment::TMN_ZRZM_FILE,
                    'user_id' => $businesss->user_id,
                    'ep_id' => -1,
                ];
            }
            if ($businesss->gdhjy_img){
                $attachments[] = [
                    'path' => $businesss->gdhjy_img,
                    'type' => Attachment::TMN_GDHJY_FILE,
                    'user_id' => $businesss->user_id,
                    'ep_id' => -1,
                ];
            }
        }

        return $attachments;
    }
}