<?php
/**
 * Banner 图数据迁移
 * User: lzs
 * Date: 2020/12/7
 * Time: 17:21
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Models\Attachment;
use App\Models\Banner;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class Banners
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // Banner 图数据迁移
        $data = self::banners($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('banners', $data['banners'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取 Banner 图数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function banners(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('config_banner')->where('status', '<>', -1);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $banners = $baseQuery->select(['id', 'type', 'title', 'description', 'pic', 'picm', 'url', 'target', 'sortId', 'status'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        $attachmentPaths = [];
        foreach ($banners as $banner){
            if ($banner->pic){
                $attachmentPaths[] = $banner->pic;
            }
            if ($banner->picm){
                $attachmentPaths[] = $banner->picm;
            }
        }

        $attachments = Attachment::query()->whereIn('path', $attachmentPaths)->pluck('id', 'path')->all();

        // 处理数据
        $data = [];
        $typeMap = [
            0 => Banner::HOME_BANNER,
            6 => Banner::LOGIN_BANNER,
            7 => Banner::TRADEMARK_BANNER
        ];
        $targetMap = [
            0 => '_self',
            1 => '_blank',
        ];
        $time = date('Y-m-d H:i:s');
        foreach ($banners  as $banner){
            if (!isset($typeMap[$banner->type])){
                continue;
            }

            $data[] = [
                'title' => $banner->title,
                'description' => $banner->description,
                'type' => $typeMap[$banner->type],
                'link' => $banner->url ?: '',
                'target' => isset($targetMap[$banner->target]) ? $targetMap[$banner->target] : '_self',
                'enable' => $banner->status == 1 ? Banner::ENABLE_YES : Banner::ENABLE_NO,
                'order' => intval($banner->sortId),
                'pc_banner_id' => isset($attachments[$banner->pic]) ? $attachments[$banner->pic] : 0,
                'mobile_banner_id' => ($typeMap[$banner->type] == Banner::HOME_BANNER && isset($attachments[$banner->picm])) ? $attachments[$banner->picm] : 0,
                'created_at' => $time,
                'updated_at' => $time,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'banners' => $data
        ];
    }
}
