<?php
/**
 * 佣金明细数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\CommissionBill;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class CommissionBills
{
    private static $original_table = 'users_promotion_log'; # 老数据表名
    private static $new_table = 'commission_bills'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        $productTypes = [
            'domain' => CommissionBill::PRODUCT_DOMAIN_REG,
            'tm' => CommissionBill::PRODUCT_TM_IPR,
            'cloud' => CommissionBill::PRODUCT_SERVER,
            'host' => CommissionBill::PRODUCT_VIRTUAL_HOST,
            'website' => CommissionBill::PRODUCT_GW_WEB,
            'companyservice' => CommissionBill::PRODUCT_CUSTOM_SERVICE,
            'ssl' => CommissionBill::PRODUCT_SSL,
            'tmjiaoyi' => CommissionBill::PRODUCT_TM_TRADE,
            'etpemail' => CommissionBill::PRODUCT_ETP_EMAIL,
            'domaintrade' => CommissionBill::PRODUCT_DOMAIN_TRADE,
            'miniprogram' => CommissionBill::PRODUCT_MINI_PROGRAM,
        ];

        foreach ($originals  as $original){
            $data[] = [
                'id' => $original->id,
                'child_user_id' => $original->userid,
                'parent_user_id' => $original->promoter_id,
                'product_type' => isset($productTypes[$original->product_type]) ? $productTypes[$original->product_type] : $original->product_type,
                'product_id' => $original->product_id,
                'money' => ($original->points) * 100,
                'balance' => 0,
                'order_num' => '',
                'created_at' => $original->logtime,
                'updated_at' => $original->logtime,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}