<?php
/**
 * 佣金产品数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\CommissionProduct;
use App\Models\Product;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class CommissionProducts
{
    private static $original_table = 'products_promotion'; # 老数据表名
    private static $new_table = 'commission_products'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table)->whereNotIn('product_type',['database','zz']);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        $productTypes = [
            'any' => CommissionProduct::PRODUCT_ANY,
            'domain' => Product::PRODUCT_DOMAIN_REG,
            'tm' => Product::PRODUCT_TM_IPR,
            'cloud' => Product::PRODUCT_SERVER,
            'host' => Product::PRODUCT_VIRTUAL_HOST,
            'website' => Product::PRODUCT_GW_WEB,
            'companyservice' => Product::PRODUCT_CUSTOM_SERVICE,
            'ssl' => Product::PRODUCT_SSL,
            'tmjiaoyi' => Product::PRODUCT_TM_TRADE,
            'etpemail' => Product::PRODUCT_ETP_EMAIL,
            'domaintrade' => Product::PRODUCT_DOMAIN_TRADE,
            'miniprogram' => Product::PRODUCT_MINI_PROGRAM,
        ];

        foreach ($originals  as $original){
            $data[] = [
                'id' => $original->id,
                'product_type' => isset($productTypes[$original->product_type]) ? $productTypes[$original->product_type] : '',
                'product_id' => $original->product_id,
                'type' => $original->type,
                'commission' => $original->value,
                'group_id' => $original->grade_id,
                'created_at' => date('Y-m-d H:i:s'),
                'updated_at' => date('Y-m-d H:i:s'),
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}