<?php
/**
 * 配置文件迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\Attachment;
use App\Models\Product;
use App\Models\SysConfig;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class Configs
{
    private static $original_table = 'config'; # 老数据表名
    private static $new_table = ''; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        $sysConfigs = $data['data'];

        $sysConfigService = (new SysConfig());
        foreach ($sysConfigs as $key => $sysConfig){
            switch ($key){
                case SysConfig::BASIC_MODULE: # 基本设置
                    $sysConfigService->store($sysConfig,SysConfig::BASIC_MODULE);
                    break;
                case SysConfig::MEMBER_MODULE: # 会员设置
                    $sysConfigService->store($sysConfig,SysConfig::MEMBER_MODULE);
                    break;
                case SysConfig::NOTICE_MODULE: # 通知设置
                    $sysConfigService->store($sysConfig,SysConfig::NOTICE_MODULE);
                    break;
                case SysConfig::PRODUCT_MODULE: # 产品设置
                    $sysConfigService->store($sysConfig,SysConfig::PRODUCT_MODULE);
                    break;
                case SysConfig::FINANCE_MODULE: # 财务设置
                    $sysConfigService->store($sysConfig,SysConfig::FINANCE_MODULE);
                    break;
                case SysConfig::TOP_UP_MODULE: # 充值设置
                    $sysConfigService->store($sysConfig,SysConfig::TOP_UP_MODULE);
                    break;
                case SysConfig::SAFETY_MODULE: # 安全设置
                    $sysConfigService->store($sysConfig,SysConfig::SAFETY_MODULE);
                    break;
                case SysConfig::INTERFACE_MODULE: # 接口设置
                    $sysConfigService->store($sysConfig,SysConfig::INTERFACE_MODULE);
                    break;
            }
        }

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->select(['key','value'])
            ->pluck('value','key')
            ->toArray();

        // 处理数据
        $data = [];
        foreach ($originals  as $key => $original){
            $original = json_decode(base64_decode($original),true);
            switch ($key){
                case 'basic': # 基本配置
                    $data['basic'] = self::basicDataConversion($original);
                    break;
                case 'member': # 会员配置
                    $data['member'] = self::memberDataConversion($original);
                    break;
                case 'finance': # 财务配置
                    $data['finance'] = self::financeDataConversion($original);
                    break;
                case 'recharge': # 充值配置
                    $data['top_up'] = self::topUpDataConversion($original);
                    break;
                case 'product': # 产品功能配置
                    $data['product'] = self::productDataConversion($original);
                    break;
                case 'email': # 邮件通知配置
                    $data['email'] = self::emailDataConversion($original);
                    break;
                case 'smg': # 短信通知配置
                    $data['sms'] = self::smsDataConversion($original);
                    break;
                case 'safety': # 短信通知配置
                    $data['safety'] = self::safetyDataConversion($original);
                    break;
                case 'interface': # 接口配置
                    $data['interface'] = self::interfaceDataConversion($original);
                    break;
            }
        }

        $data['notice'] = $data['email'] + $data['sms'];

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }

    /**
     * 基本配置数据转换
     * @param $original
     * @return array
     * @author ePower JCQ
     * @date 2020/11/27
     */
    private static function basicDataConversion($original)
    {
        $qqTypes = [
            '0' => 'personal',
            '1' => 'marketing',
        ];

        // 附件迁移映射

        $whereIn = [];
        if (isset($original['userLogo'])){
            $whereIn[] = $original['userLogo'];
        }
        if (isset($original['mobileLogo'])){
            $whereIn[] = $original['mobileLogo'];
        }
        if (isset($original['wxLogo'])){
            $whereIn[] = $original['wxLogo'];
        }
        $attachments = Attachment::query()
            ->whereIn('path',$whereIn)
            ->pluck('id','path')
            ->toArray();

        $data = [
            'site_name' => $original['site_name'],
            'site_slogan' => $original['welcome'],
            'icp_code' => $original['icp_code'],
            'police_code' => isset($original['police_title']) ? $original['police_title'] : '',
            'mobile_terminal_enable' => $original['enablePhone'] ? true : false,
            'company_name' => $original['company_name'],
            'company_address' => $original['company_address'],
            'service_hotline' => $original['service_hotline'],
            'service_time' => $original['service_hours'],
            'qq_type' => isset($original['qqType']) && isset($qqTypes[$original['qqType']]) ? $qqTypes[$original['qqType']] : 'personal',
            'personal_qq' => $original['qq'],
            'marketing_qq' => isset($original['companyQQLink']) ? $original['companyQQLink'] : '',
            'qq_link' => isset($original['companyQQLink']) ? $original['companyQQLink'] : '',
            'app_name' => $original['program_name'],
            'site_link' => $original['program_url'],
            'email' => $original['email'],
            'copyright' => $original['copyright'],
            'footer_info' => htmlspecialchars_decode($original['bottom_text']),
            'statistics_code' => htmlspecialchars_decode($original['statisticalCode']),
            'pc_logo_id' => isset($attachments[$original['userLogo']]) ? $attachments[$original['userLogo']] : 0,
            'mobile_logo_id' => isset($original['mobileLogo']) && isset($attachments[$original['mobileLogo']]) ? $attachments[$original['mobileLogo']] : 0,
            'qr_code_id' => isset($original['wxLogo']) && isset($attachments[$original['wxLogo']]) ? $attachments[$original['wxLogo']] : 0,
            'favicon_id' => 0,
            'qr_code_cs_id' => 0,
        ];

        return $data;
    }

    /**
     * 会员配置数据转换
     * @param $original
     * @return array
     * @author ePower JCQ
     * @date 2020/11/27
     */
    private static function memberDataConversion($original)
    {
        // 登录方式新老版本映射
        $loginMethods = [
            'id' => 'id',    # ID登录
            'email' => 'email',    # 邮箱登录
            'mobile'=> 'phone_number', # 手机号码登录
            'name' => 'username'  # 用户名登录
        ];

        $originalLoginMethods = explode(',',$original['loginWay']); # 原登录方式

        $newLoginMethods = []; # 转换后的登录方式
        if($originalLoginMethods){
            foreach ($originalLoginMethods as $originalLoginMethod){
                if(isset($loginMethods[$originalLoginMethod])){
                    $newLoginMethods[] = $loginMethods[$originalLoginMethod];
                }
            }
        }

        $data = [
            'sign_up_enable' => $original['enableRegister'] ? true : false,
            'sign_up_sms_enable' => isset($original['mobileRegister']) && $original['mobileRegister'] ? true : false,
            'sign_up_detail_enable' => isset($original['detailRegisterSwitch']) && $original['detailRegisterSwitch'] ? true : false,
            'login_enable' => $original['enableLogin'] ? true : false,
            'login_methods' => $newLoginMethods,
            'wx_auto_login_enable' => false,
            'wx_gzh_login_enable' => isset($original['enableMobileWxLogin']) && $original['enableMobileWxLogin'] ? true : false,
            'wx_gzh_app_id' => isset($original['app_id']) ? $original['app_id'] : '',
            'wx_gzh_app_secret' => isset($original['app_secret']) ? $original['app_secret'] : '',
            'wx_gzh_token' => isset($original['app_token']) ? $original['app_token'] : '',
            'wx_gzh_ase_key' => isset($original['ase_key']) ? $original['ase_key'] : '',
            'qq_login_enable' => isset($original['enableQqLogin']) && $original['enableQqLogin'] ? true : false,
            'qq_app_id' => isset($original['qq_login_app_id']) ? $original['qq_login_app_id'] : '',
            'qq_app_key' => isset($original['qq_login_app_key']) ? $original['qq_login_app_key'] : '',
        ];

        return $data;
    }

    /**
     * 财务配置数据转换
     * @param $original
     * @return array
     * @author ePower JCQ
     * @date 2020/11/27
     */
    private static function financeDataConversion($original)
    {

        $data = [
            'invoice_enable' => $original['invoiceSwitch'] ? true : false,
            'invoice_handling_fee_percent' => $original['proportionInvoice'],
            'invoice_postage' => $original['invoicePostage'],
            'invoice_real_name_enable' => $original['invoiceRealName'] ? true : false,
            'invoice_rise_real_name_enable' => $original['invoiceRiseRealName'] ? true : false,
            'electronic_invoice_enable' => isset($original['invoiceElectron']) && $original['invoiceElectron'] ? true : false,
            'withdraw_enable' => $original['fundsSwitch'] ? true : false,
            'min_withdraw' => $original['minFunds'],
            'withdraw_unit' => $original['funds'],
            'withdraw_handling_fee_percent' => $original['fundsFree'],
            'withdraw_real_name_enable' => $original['fundRealName'] ? true : false,
        ];

        return $data;
    }

    /**
     * 充值配置数据转换
     * @param $original
     * @return array
     * @author ePower JCQ
     * @date 2020/11/27
     */
    private static function topUpDataConversion($original)
    {
        $data = [
            'top_up_real_name_enable' => isset($original['authtype']) && $original['authtype'] ? true : false,
            'top_up_min' => $original['minRecharge'],
            'alipay_page_enable' => $original['alipaySwitch'] ? true : false,
            'alipay_wap_enable' => $original['wapPaySwitch'] ? true : false,
            'alipay_pid' => $original['alipayPartner'],
            'alipay_key' => $original['alipayKey'],
            'wxpay_jsapi_enable' => $original['wxpaySwitch'] ? true : false,
            'wxpay_mweb_enable' => isset($original['wxpayh5']) && $original['wxpayh5'] ? true : false,
            'wxpay_mch_id' => $original['wxpayMchid'],
            'wxpay_mch_key' => $original['wxpayKey'],
            'wxpay_app_id' => $original['wxpayAppID'],
            'wxpay_app_secret' => $original['wxpaySecret'],
            'manual_pay_enable' => isset($original['manualPay']) && $original['manualPay'] ? true : false,
            'manual_pay_content' => htmlspecialchars_decode($original['manualPayContent']),
        ];

        return $data;
    }

    /**
     * 产品功能配置数据转换
     * @param $original
     * @return array
     * @author ePower JCQ
     * @date 2020/11/27
     */
    private static function productDataConversion($original)
    {
        // 销售产品新老版本映射
        $saleableProducts = [
            'product_tm' => Product::PRODUCT_TM_IPR,
            'product_tmjiaoyi' => Product::PRODUCT_TM_TRADE,
            'product_website' => Product::PRODUCT_GW_WEB,
            'product_miniprogram' => Product::PRODUCT_MINI_PROGRAM,
            'product_etpemail' => Product::PRODUCT_ETP_EMAIL,
            'product_companyservice' => Product::PRODUCT_CUSTOM_SERVICE,
            'product_domain' => Product::PRODUCT_DOMAIN_REG,
            'product_domaintrade' => Product::PRODUCT_DOMAIN_TRADE,
            'product_ssl' => Product::PRODUCT_SSL,
            'product_cloud' => Product::PRODUCT_SERVER,
            'product_host' => Product::PRODUCT_VIRTUAL_HOST,
        ];
        $newSaleableProducts = []; # 转换后的销售产品
        foreach ($saleableProducts as $salekey => $saleableProduct){
            if(isset($original[$salekey]) && $original[$salekey] == 'yes'){
                $newSaleableProducts[] = $saleableProducts[$salekey];
            }
        }

        //可使用优惠券的产品新老版本映射
        $couponProducts = [
            'card_tm' => Product::PRODUCT_TM_IPR,
            'card_tmjiaoyi' => Product::PRODUCT_TM_TRADE,
            'card_website' => Product::PRODUCT_GW_WEB,
            'card_miniprogram' => Product::PRODUCT_MINI_PROGRAM,
            'card_etpemail' => Product::PRODUCT_ETP_EMAIL,
            'card_companyservice' => Product::PRODUCT_CUSTOM_SERVICE,
            'card_domain' => Product::PRODUCT_DOMAIN_REG,
            'card_domaintrade' => Product::PRODUCT_DOMAIN_TRADE,
            'card_ssl' => Product::PRODUCT_SSL,
            'card_cloud' => Product::PRODUCT_SERVER,
            'card_host' => Product::PRODUCT_VIRTUAL_HOST,
        ];
        $newCouponProducts = []; # 转换后的可使用优惠券的产品
        foreach ($couponProducts as $couponkey => $couponProduct){
            if(isset($original[$couponkey]) && $original[$couponkey] == 'yes'){
                $newCouponProducts[] = $couponProducts[$couponkey];
            }
        }

        // 附件迁移映射
        if (isset($original['commissionBg'])){
            $attachments = Attachment::query()
                ->whereIn('path',[$original['commissionBg']])
                ->pluck('id','path')
                ->toArray();
        }else{
            $attachments = [];
        }

        $data = [
            'fawen_jifu_enable' => isset($original['is_fawenjifu']) && $original['is_fawenjifu'] ? true : false,
            'fawen_jifu_post_fee' => isset($original['fawenjifu_price']) ? $original['fawenjifu_price'] : 0,
            'tm_query_limit_enable' => $original['tm_search'] ? true : false,
            'visitor_tm_query_frequency' => $original['Tourist'],
            'tm_query_captcha_enable' => $original['tm_search_code'] ? true : false,
            'tm_needs_form_enable' => $original['tm_need_input'] ? true : false,
            'tm_applicant_privacy_protection_enable' => isset($original['privacy_protection']) && $original['privacy_protection'] ? true : false,
            'tm_applicant_privacy_protection_phone' => isset($original['privacy_mobile']) ? $original['privacy_mobile'] : '',
            'tm_applicant_privacy_protection_name' => isset($original['privacy_name']) ? $original['privacy_name'] : '',
            'tm_applicant_privacy_protection_province' => '',
            'tm_applicant_privacy_protection_city' => '',
            'tm_applicant_privacy_protection_district' => '',
            'tm_applicant_privacy_protection_postcode' => '',
            'tm_query_limit_ips' => isset($original['tm_search_limit_ip']) ? $original['tm_search_limit_ip'] : '',
            'tm_query_limit_areas' => isset($original['tm_search_limit_ip_area']) ? $original['tm_search_limit_ip_area'] : '',
            'tmt_min_commission_percent' => $original['tmjiaoyi_commission'],
            'tmt_auto_sync_enable' => isset($original['tmjiaoyi_autoupdate']) && $original['tmjiaoyi_autoupdate'] ? true : false,
            'gw_reserved_domains' => isset($original['reserved_domains']) && $original['reserved_domains'] ? $original['reserved_domains'] : '',
            'gw_authenticate_enable' => isset($original['gw_authenticate_enable']) && $original['gw_authenticate_enable'] ? true : false,
            'dt_min_commission_percent' => $original['domaintrade_commission'],
            'dt_auto_sync_enable' => isset($original['domaintrade_switch']) && $original['domaintrade_switch'] ? true : false,
            'vhost_12_months_discount' => $original['oneYearDiscount'],
            'vhost_24_months_discount' => $original['twoYearDiscount'],
            'vhost_36_months_discount' => $original['threeYearDiscount'],
            'vhost_panel_functions' => [
                0 => 'status_manage',
                1 => 'upgrade',
                2 => 'renew',
            ],
            'saleable_products' => $newSaleableProducts,
            'promotion_commission_enable' => $original['commission'] ? true : false,
            'promotion_bgi_id' => isset($original['commissionBg']) && isset($attachments[$original['commissionBg']]) ? $attachments[$original['commissionBg']] : 0,
            'tm_trade_share_bgi_id' => config('epower.product.tm_trade_share_bgi_id') ? config('epower.product.tm_trade_share_bgi_id') : 0,
            'promotion_description' => $original['commissionDesc'],
            'coupon_enable' => $original['card'] ? true : false,
            'coupon_products' =>$newCouponProducts,
            'sync_notification_enable' => false,
            'notify_disable_start' => '',
            'notify_disable_end' => '',
            'tm_trade_holder_enable' => true,
        ];

        return $data;
    }


    /**
     * 邮件配置数据转换
     * @param $original
     * @return array
     * @author ePower JCQ
     * @date 2020/11/27
     */
    private static function emailDataConversion($original)
    {
        $data = [
            'mail_host' => $original['smtp'],
            'mail_port' => $original['emailPort'],
            'mail_encryption' => $original['emailSecure'],
            'mail_username' => $original['emailUsername'],
            'mail_password' => $original['emailPassword'],
            'mail_from_address' => $original['emailUsername'],
            'mail_from_name' => isset($original['displayName']) && $original['displayName'] ? $original['displayName'] : '',
        ];

        return $data;
    }

    /**
     * 短信配置数据转换
     * @param $original
     * @return array
     * @author ePower JCQ
     * @date 2020/11/27
     */
    private static function smsDataConversion($original)
    {
        // 短信频道新老版本映射
        $smsChannels = [
            '3' => 'dahan',
            '6' => 'yuntongxun',
        ];

        $data = [
            'sms_channel' => isset($smsChannels[$original['firstChannel']]) ? $smsChannels[$original['firstChannel']] : 'yuntongxun',
            'sms_dahan' => [
                'account_sid' => $original['smgAcountDh'],
                'auth_token' => $original['smgPasswordDh'],
                'app_id' => $original['smgChannelDh'],
            ],
            'sms_yuntongxun' => [
                'account_sid' => isset($original['smgAcountYtx']) ? $original['smgAcountYtx'] : '',
                'account_token' => isset($original['smgTokenYtx']) ? $original['smgTokenYtx'] : '',
                'app_id' => isset($original['smgAppidYtx']) ? $original['smgAppidYtx'] : '',
                'is_sub_account' => false,
            ],
        ];

        return $data;
    }

    /**
     * 安全配置数据转换
     * @param $original
     * @return array
     * @author ePower JCQ
     * @date 2020/11/27
     */
    private static function safetyDataConversion($original)
    {
        // 后台安全验证新老版本映射
        $verificationTypes = [
            'email' => 'email',
            'mobile'=> 'sms',
        ];
        $originalVerificationTypes = explode(',',$original['safetyVerification']); # 原登录方式
        $newVerificationTypes = []; # 转换后的后台安全验证
        if($originalVerificationTypes){
            foreach ($originalVerificationTypes as $originalVerificationType){
                if(isset($verificationTypes[$originalVerificationType])){
                    $newVerificationTypes[] = $verificationTypes[$originalVerificationType];
                }
            }
        }

        $data = [
            'web_close_enable' => $original['offSite'] ? true : false,
            'admin_prefix' => $original['adminModule'],
            'admin_safety_verification_types' => $newVerificationTypes,
            'pwd_error_max_times' => $original['maxLoginErrorCount'],
            'limit_ips' => $original['ipLimit'],
        ];

        return $data;
    }

    /**
     * 接口配置数据转换
     * @param $original
     * @return array
     * @author ePower JCQ
     * @date 2020/11/27
     */
    private static function interfaceDataConversion($original)
    {
        $data = [
            'api_id' => $original['apiID'],
            'api_url' => $original['apiURL'],
            'api_key' => $original['apiKey'],
            'app_key' => isset($original['AppKey']) ? $original['AppKey'] : '',
            'app_ip' => isset($original['AppIp']) ? $original['AppIp'] : '',
        ];

        return $data;
    }
}
