<?php
/**
 * 工商财税产品数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class CsProducts
{
    private static $original_table = 'company_service'; # 老数据表名
    private static $new_table = 'cs_products'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        // 产品分类
        $classes = $connection->table('company_servicecls')->pluck('id','enName')->toArray();

        foreach ($originals  as $original){
            $data[] = [
                'id' => $original->id,
                'name' => $original->title,
                'class_id' => isset($classes[$original->type]) ? $classes[$original->type] : 0,
                'is_out_link' => $original->is_outlink,
                'out_link' => $original->url,
                'tag' => '',
                'introduction' => $original->info,
                'content' => htmlspecialchars_decode($original->content),
                'cs_product_image' => $original->pic,
                'order' => $original->sortid,
                'enable' => $original->status,
                'created_at' => date('Y-m-d H:i:s'),
                'updated_at' => date('Y-m-d H:i:s'),
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}
