<?php
/**
 * 工商财税业务数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\CustomService;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class CustomServices
{
    private static $original_table = 'service_need'; # 老数据表名
    private static $new_table = 'custom_services'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table)
            ->whereIn('is_pay', [0,1,2]);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        // 付款状态映射
        $payStatusMaps = [
            '0'=> CustomService::unpaid_status,
            '1'=> CustomService::paid_status,
            '2'=> CustomService::refunded_status,
        ];

        foreach ($originals  as $original){
            $data[] = [
                'id' => $original->id,
                'user_id' => $original->userid,
                'product_id' => $original->cid,
                'attribute_id' => 0,
                'attribute_name' => '',
                'detail' => $original->content,
                'status' => $original->status,
                'pay_status' => $payStatusMaps[$original->is_pay],
                'sale_price' => ($original->money > 0) ? ($original->money * 100) : 0,
                'audit_memo' => isset($original->remarks) && $original->remarks ? $original->remarks : '',
                'created_at' => $original->datetime,
                'updated_at' => $original->datetime,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}
