<?php
/**
 * 客服人员数据迁移
 * User: lzs
 * Date: 2020/10/28
 * Time: 11:20
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class CustomerServiceStaff
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 客服人员数据迁移
        $data = self::staffs($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('customer_service_staff', $data['staffs'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取客服人员数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function staffs(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('customerservice')->where('isDelete', '0');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $staffs = $baseQuery->select(['id', 'name', 'adminID', 'telephone', 'qq', 'isRelation', 'ownerPermission'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        $time = date('Y-m-d H:i:s');
        foreach ($staffs  as $staff){
            $data[] = [
                'id' => $staff->id,
                'name' => $staff->name,
                'admin_id' => $staff->adminID,
                'fixed_number' => $staff->telephone,
                'qq' => $staff->qq,
                'auto_assoc_enable' => $staff->isRelation == 1 ? 1 : 0,
                'only_affiliates' => $staff->ownerPermission,
                'avatar_id' => 0,
                'qr_code_id' => 0,
                'distributed_at' => null,
                'created_at' => $time,
                'updated_at' => $time,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'staffs' => $data
        ];
    }
}
