<?php
/**
 * 域名push数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class DomainPushes
{
    private static $original_table = 'domains_push'; # 老数据表名
    private static $new_table = 'domain_pushes'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        // push关联的域名
        $originalDomains = $connection->table('domains_push_domain')
            ->get();
        $domains = [];
        foreach ($originalDomains as $originalDomain){
            $domains[$originalDomain->push_id][] = $originalDomain->strdomain;
        }

        foreach ($originals  as $original){
            $domain = isset($domains[$original->id]) ? $domains[$original->id] : [];

            $data[] = [
                'id' => $original->id,
                'from_user_id' => $original->src_userid,
                'to_user_id' => $original->dest_userid,
                'domain' => json_encode($domain),
                'status' => $original->status,
                'remark' => $original->memo,
                'push_at' => $original->create_time,
                'created_at' => $original->create_time,
                'updated_at' => $original->create_time,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}