<?php
/**
 * 域名注册数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\DomainReg;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class DomainRegs
{
    private static $original_table = 'domains'; # 老数据表名
    private static $new_table = 'domain_regs'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);;

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        foreach ($originals  as $original){
            if($original->is_in_transaction == 1){
                $original->status = DomainReg::trading_status;
            }
            $data[] = [
                'id' => $original->id,
                'user_id' => $original->user_id,
                'product_id' => $original->domain_type,
                'template_id' => isset($original->contactor_id) && $original->contactor_id ? $original->contactor_id : 0,
                'domain' => $original->strdomain,
                'registered_at' => $original->register_time && $original->register_time > '1980-00-00 00:00:00' ? $original->register_time : ($original->start_time && $original->start_time > '1980-00-00 00:00:00' ? $original->start_time : null),
                'expired_at' => $original->end_time,
                'status' => $original->status,
                'pay_status' => DomainReg::paid_status,
                'notify_stage' => $original->notify_stage,
                'created_at' => $original->start_time && $original->start_time > '1980-00-00 00:00:00' ? $original->start_time : null,
                'updated_at' => $original->start_time && $original->start_time > '1980-00-00 00:00:00' ? $original->start_time : null,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}
