<?php
/**
 * 域名模板数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\Area;
use App\Models\DomainTemplate;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class DomainTemplates
{
    private static $original_table = 'contactors'; # 老数据表名
    private static $new_table = 'domain_templates'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        $areas =  Area::query()->pluck('name','code')->toArray();

        foreach ($originals  as $original){
            $data[] = [
                'id' => $original->id,
                'user_id' => $original->user_id,
                'domain_type' => $original->contactor_type,
                'registrant_type' => $original->cert_type,
                'cert_type' => isset($original->ctype) ? $original->ctype : DomainTemplate::id_certificate_type,
                'cert_num' => $original->cert_no_org ? $original->cert_no_org : ($original->cert_no_personal ? $original->cert_no_personal : ''),
                'name' => $original->name ? $original->name : '',
                'org' => $original->org,
                'last_name' => $original->last_name,
                'first_name' => $original->first_name,
                'province' => $original->state_cn,
                'city' => $original->city_cn,
                'district' => $original->area_cn,
                'address' => $original->address,
                'org_en' => $original->org_en,
                'last_name_en' => $original->last_name_en,
                'first_name_en' => $original->first_name_en,
                'province_en' => $original->state,
                'city_en' => $original->city,
                'district_en' => $original->area,
                'province_code' => $original->state,
                'city_code' => $original->city,
                'district_code' => $original->area,
                'address_en' => $original->address_en,
                'email' => $original->email,
                'phone' => $original->phone,
                'fax' => $original->fax,
                'zipcode' => $original->zipcode,
                'credit_code' => $original->cert_no_org,
                'domain_template_business_file' => $original->cert_file_org,
                'is_default' => $original->is_default,
                'status' => $original->cert_status,
                'rnvc_status' => $original->rnvc_status,
                'audit_memo' => $original->memo,
                'created_at' => $original->add_time == '0000-00-00 00:00:00' ? null : $original->add_time,
                'updated_at' => $original->edit_time == '0000-00-00 00:00:00' ? null : $original->edit_time,
                'domain_template_org_file' => $original->cert_file_personal ? $original->cert_file_personal : $original->cert_file_org,
                'unique_id' => $original->contactor_id ? $original->contactor_id : '',
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}
