<?php
/**
 * 域名交易记录数据迁移
 * User: lzs
 * Date: 2020/10/9
 * Time: 11:10
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class DomainTradeRecords
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 交易记录数据迁移
        $data = self::trades($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('domain_trade_records', $data['trades'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取域名交易记录数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function trades(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('dt_list')
            ->where('status', 2);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $trades = $baseQuery->select(['id', 'original_user_id', 'user_id', 'remote_id', 'name', 'source', 'pay_at'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        $time = date('Y-m-d H:i:s');
        foreach ($trades  as $trade){
            $data[] = [
                'seller_id' => $trade->original_user_id,
                'buyer_id' => $trade->user_id,
                'trade_id' => $trade->id,
                'am_unique_id' => $trade->remote_id,
                'order_id' => 0,
                'domains' => $trade->name,
                'is_local' => $trade->source == 1 ? 1 : 0,
                'completed_at' => $trade->pay_at,
                'created_at' => $time,
                'updated_at' => $time,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'trades' => $data
        ];
    }

}