<?php
/**
 * 域名交易数据迁移
 * User: lzs
 * Date: 2020/10/9
 * Time: 15:04
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Models\DomainTrade;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class DomainTrades
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 域名交易数据迁移
        $data = self::trades($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('domain_trades', $data['trades'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取域名交易数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function trades(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('dt_list')
            ->where('source', 1)
            ->orWhere(function ($query){
                $query->where('source', '<>', 1)
                    ->where('status', 2);
            });
        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $columns = ['id', 'name', 'prefix', 'suffix', 'user_id', 'original_user_id', 'structure_num', 'boutique', 'c_type', 'd_type', 'not_type', 'details_type', 'remote_id', 'auction_cycle', 'count', 'introduction', 'remark', 'source', 'registrant', 'sale_type', 'commission_rate', 'init_price', 'final_price', 'audit_status', 'audit_text', 'status', 'on_sale', 'registration_at', 'expire_at', 'sale_start_at', 'sale_end_at', 'pay_at'];
        $trades = $baseQuery->select($columns)
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        $time = date('Y-m-d H:i:s');
        foreach ($trades  as $trade){
            if (!in_array($trade->status, array_keys(DomainTrade::$tradingStatusNames))){
                continue;
            }
            if ($trade->status == 1 && $trade->on_sale == 0 && $trade->audit_status == 0){
                $status = DomainTrade::STATUS_AUDIT_PENDING;
            }elseif ($trade->status == 1 && $trade->on_sale == 0 && $trade->audit_status == 2){
                $status = DomainTrade::STATUS_AUDIT_NOT_PASSED;
            }elseif ($trade->status == 1 && $trade->on_sale == 1 && $trade->audit_status == 1){
                $status = DomainTrade::STATUS_ON_SHELF;
            }elseif ($trade->status == 1 && $trade->on_sale == 0 && $trade->audit_status == 1){
                $status = DomainTrade::STATUS_USER_OFF_SHELF;
            }elseif ($trade->status == 2 && $trade->on_sale == 0 && $trade->audit_status == 1){
                $status = DomainTrade::STATUS_BEEN_SOLD;
            }elseif ($trade->status == 3){
                $status = DomainTrade::STATUS_EXPIRED;
            }else{
                continue;
            }

            $data[] = [
                'name' => $trade->name,
                'prefix' => $trade->prefix,
                'suffix' => $trade->suffix,
                'detail_info' => '',
                'is_local' => $trade->source == 1 ? 1 : 0,
                'seller_user_id' => $trade->original_user_id,
                'buyer_user_id' => $trade->user_id,
                'structure_num' => intval($trade->structure_num),
                'boutique' => intval($trade->boutique),
                'c_type' => $trade->c_type,
                'd_type' => intval($trade->d_type),
                'not_type' => intval($trade->not_type),
                'details_type' => intval($trade->details_type),
                'am_unique_id' => intval($trade->remote_id),
                'length' => intval($trade->auction_cycle),
                'package_count' => intval($trade->count),
                'introduction' => $trade->introduction,
                'remark' => strval($trade->remark),
                'source' => $trade->source ?: '',
                'registrant' => $trade->registrant ?: '',
                'sale_type' => $trade->sale_type,
                'commission_rate' => $trade->commission_rate,
                'order' => 0,
                'price' => bcmul($trade->init_price, 100, 0),
                'final_price' => bcmul($trade->final_price, 100, 0),
                'trading_status' => $trade->status,
                'status' => $status,
                'audit_text' => $trade->audit_text,
                'domain_registration_at' => $trade->registration_at,
                'domain_expired_at' => $trade->expire_at,
                'start_at' => $trade->sale_start_at,
                'end_at' => $trade->sale_end_at,
                'completed_at' => $trade->pay_at,
                'created_at' => $time,
                'updated_at' => $time,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'trades' => $data
        ];

    }

}

