<?php
/**
 * 域名转入数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\DomainTransferIn;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class DomainTransferIns
{
    private static $original_table = 'domains_transferin'; # 老数据表名
    private static $new_table = 'domain_transfer_ins'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);;

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        foreach ($originals  as $original){
            $data[] = [
                'id' => $original->id,
                'user_id' => $original->user_id,
                'domain' => $original->strdomain,
                'template_id' => $original->contactor_id,
                'status' => $original->status == 5 ? DomainTransferIn::failed_status : $original->status,
                'pay_status' => $original->status == 5 ? DomainTransferIn::refunded_status : DomainTransferIn::paid_status,
                'audit_memo' => $original->memo,
                'transfer_at' => $original->transfer_date == '0000-00-00 00:00:00' ? date('Y-m-d H:i:s') : $original->transfer_date,
                'unique_id' => $original->remote_id,
                'created_at' => $original->add_date,
                'updated_at' => $original->add_date,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}

