<?php
/**
 * 企业邮箱联系人数据迁移
 * User: lzs
 * Date: 2020/10/13
 * Time: 17:35
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class EtpEmailCustomers
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 企业邮箱联系人数据迁移
        $data = self::customers($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('etp_email_customers', $data['customers'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取企业邮箱联系人数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function customers(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('enterprise_email');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $emails = $baseQuery->select(['id', 'api_customer_id', 'customer_name', 'customer_email', 'customer_mobile', 'customer_linkman', 'corp_name'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        foreach ($emails  as $email){
            $data[] = [
                'email_id' => $email->id,
                'xw_customer_id' => $email->api_customer_id,
                'name' => strval($email->customer_name),
                'email' => strval($email->customer_email),
                'mobile' => strval($email->customer_mobile),
                'linkman' => strval($email->customer_linkman),
                'corp_name' => strval($email->corp_name),
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'customers' => $data
        ];
    }
}

