<?php
/**
 * 企业邮箱数据迁移
 * User: lzs
 * Date: 2020/10/13
 * Time: 17:35
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Models\Attachment;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class EtpEmails
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 企业邮箱数据迁移
        $data = self::emails($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('etp_emails', $data['emails'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取用户认证数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function emails(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('enterprise_email');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $emails = $baseQuery->select(['id', 'user_id', 'product_id', 'domain_name', 'domain_id', 'max_user', 'space_quota', 'archive_quota', 'admin', 'init_pwd', 'init_password', 'logo_path', 'init_logo_id', 'bgimg_path', 'init_bgimg_id', 'copyright', 'status', 'expire_time', 'start_time'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        $attachmentPaths = [];
        foreach ($emails as $email){
            if ($email->logo_path){
                $attachmentPaths[] = $email->logo_path;
            }
            if ($email->bgimg_path){
                $attachmentPaths[] = $email->bgimg_path;
            }
        }

        $attachments = Attachment::query()->whereIn('path', $attachmentPaths)->pluck('id', 'path')->all();

        // 处理数据
        $data = [];
        $time = date('Y-m-d H:i:s');
        foreach ($emails  as $email){
            $data[] = [
                'id' => $email->id,
                'user_id' => $email->user_id,
                'product_id' => $email->product_id,
                'domain_name' => $email->domain_name,
                'unique_id' => $email->domain_id,
                'user_amount' => $email->max_user,
                'space_quota' => $email->space_quota,
                'archive_quota' => $email->archive_quota,
                'admin' => $email->admin,
                'init_pwd' => $email->init_pwd,
                'init_password' => $email->init_password,
                'logo_id' => isset($attachments[$email->logo_path]) ? $attachments[$email->logo_path] : 0,
                'ep_logo_id' => $email->init_logo_id ?: '',
                'bgimg_id' => isset($attachments[$email->bgimg_path]) ? $attachments[$email->bgimg_path] : 0,
                'ep_bgimg_id' => $email->init_bgimg_id ?: '',
                'copyright' => $email->copyright ?: '',
                'status' => $email->status,
                'expired_at' => $email->expire_time,
                'created_at' => $email->start_time,
                'updated_at' => $time,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'emails' => $data
        ];
    }
}
