<?php
/**
 * 官微网站代建服务数据迁移
 * User: lzs
 * Date: 2020/10/12
 * Time: 17:32
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class GwAgentConstructions
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 网站代建服务数据迁移
        $data = self::constructions($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('gw_agent_constructions', $data['constructions'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取官微网站代建服务数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function constructions(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('gw_agent_constructions');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $constructions = $baseQuery->select(['user_id', 'contact_name', 'contact_phone', 'content', 'created_at', 'updated_at'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        foreach ($constructions  as $construction){
            $data[] = [
                'user_id' => $construction->user_id,
                'contact_name' => $construction->contact_name,
                'contact_phone' => $construction->contact_phone,
                'content' => $construction->content,
                'created_at' => $construction->created_at,
                'updated_at' => $construction->updated_at,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'constructions' => $data
        ];
    }
}