<?php
/**
 * 官微案例 数据迁移
 * User: lzs
 * Date: 2020/12/18
 * Time: 9:55
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Models\Attachment;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class GwExamples
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 官微案例 数据迁移
        $data = self::examples($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('gw_examples', $data['examples'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取 官微案例 数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function examples(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('gw_examples');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $examples = $baseQuery->select(['id', 'title', 'url', 'img', 'orderby'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        $attachmentPaths = [];
        foreach ($examples as $example){
            if ($example->img){
                $attachmentPaths[] = $example->img;
            }
        }

        $attachments = Attachment::query()->whereIn('path', $attachmentPaths)->pluck('id', 'path')->all();

        // 处理数据
        $data = [];
        $time = date('Y-m-d H:i:s');
        foreach ($examples  as $example){
            $data[] = [
                'title' => $example->title,
                'link' => $example->url,
                'img_id' => isset($attachments[$example->img]) ? $attachments[$example->img] : 0,
                'order' => $example->orderby,
                'enable' => 1,
                'created_at' => $time,
                'updated_at' => $time,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'examples' => $data
        ];
    }

}