<?php
/**
 * 官微备案码数据迁移
 * User: lzs
 * Date: 2020/10/12
 * Time: 17:08
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Models\IcpCode;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class GwIcpCodes
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 网站备案码数据迁移
        $data = self::codes($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('icp_codes', $data['codes'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取官微网站备案码数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function codes(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('gw_icpcode');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $codes = $baseQuery->select(['code', 'userid', 'websiteid', 'createtime', 'deleted_at'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        $time = date('Y-m-d H:i:s');
        foreach ($codes  as $code){
            $data[] = [
                'user_id' => $code->userid,
                'business_type' => IcpCode::BUSINESS_TYPE_GW_WEB,
                'business_id' => $code->websiteid,
                'code' => $code->code,
                'is_buy' => IcpCode::IS_BUY_YES,
                'deleted_at' => $code->deleted_at,
                'created_at' => $code->createtime,
                'updated_at' => $time,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'codes' => $data
        ];
    }

}