<?php
/**
 * 官微网站域名数据迁移
 * User: lzs
 * Date: 2020/10/12
 * Time: 17:00
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class GwWebsiteDomains
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 网站域名数据迁移
        $data = self::domains($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('gw_website_domains', $data['domains'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取官微网站绑定域名数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function domains(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('gw_websites_domains');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $domains = $baseQuery->select(['domain', 'userid', 'websiteid', 'bindat', 'deleted_at'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        $time = date('Y-m-d H:i:s');
        foreach ($domains  as $domain){
            $data[] = [
                'user_id' => $domain->userid,
                'website_id' => $domain->websiteid,
                'domain' => $domain->domain,
                'deleted_at' => $domain->deleted_at,
                'created_at' => $domain->bindat,
                'updated_at' => $time,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'domains' => $data
        ];
    }

}