<?php
/**
 * 官微过户数据迁移
 * User: lzs
 * Date: 2020/10/12
 * Time: 17:20
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class GwWebsitePushes
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 网站过户数据迁移
        $data = self::pushes($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('gw_website_pushes', $data['pushes'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取官微网站过户数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function pushes(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('gw_websites_push')->where('isDelete', '0');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $pushes = $baseQuery->select(['websiteId', 'fromUserId', 'toUserId', 'pushTime', 'adminID', 'remarks'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        $time = date('Y-m-d H:i:s');
        foreach ($pushes  as $push){
            $data[] = [
                'admin_id' => $push->adminID,
                'website_id' => $push->websiteId,
                'from_user_id' => $push->fromUserId,
                'to_user_id' => $push->toUserId,
                'remark' => $push->remarks,
                'created_at' => $push->pushTime,
                'updated_at' => $time,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'pushes' => $data
        ];
    }
}