<?php
/**
 * 官微网站数据迁移
 * User: lzs
 * Date: 2020/10/9
 * Time: 16:50
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Models\GwWebsite;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class GwWebsites
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 网站数据迁移
        $data = self::websites($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('gw_websites', $data['websites'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取官微网站数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function websites(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('gw_websites');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $websites = $baseQuery->select(['id', 'userid', 'template_number', 'webhost', 'sitename', 'type', 'server_value', 'ltd_id', 'url1', 'domain_limit', 'is_copyright', 'status', 'memo', 'expired_time', 'deleted_at', 'create_time'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        $time = date('Y-m-d H:i:s');
        $statuses = [
            '正常' => GwWebsite::STATUS_NORMAL,
            '到期' => GwWebsite::STATUS_EXPIRED,
            '管理员关闭' => GwWebsite::STATUS_CLOSED,
            '违规关闭' => GwWebsite::STATUS_VIOLATION_CLOSED,
            '删除' => GwWebsite::STATUS_DELETED,
        ];
        foreach ($websites  as $website){
            if (!in_array($website->status, array_keys($statuses))){
                continue;
            }

            $data[] = [
                'id' => $website->id,
                'user_id' => $website->userid,
                'template_id' => $website->template_number,
                'host_name' => $website->webhost,
                'site_name' => $website->sitename,
                'package_id' => $website->type,
                'server_line' => $website->server_value == 1 ? GwWebsite::SERVER_LINE_CN : GwWebsite::SERVER_LINE_HK,
                'unique_id' => $website->ltd_id,
                'free_domain' => $website->url1,
                'domain_limit' => $website->domain_limit,
                'is_copyright' => $website->is_copyright,
                'status' => $statuses[$website->status],
                'memo' => $website->memo,
                'expired_at' => $website->expired_time,
                'deleted_at' => $website->deleted_at,
                'created_at' => $website->create_time,
                'updated_at' => $time,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'websites' => $data
        ];
    }

}