<?php
/**
 * 发票申请数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\Invoice;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class Invoices
{
    private static $original_table = 'invoice'; # 老数据表名
    private static $new_table = 'invoices'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table)->whereIn('result',['-1','1']);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        $types = [
          '0' => Invoice::electronic_type, # 电子
          '1' => Invoice::paper_type, # 纸质
        ];

        $is_invoices = [
            '-1' => Invoice::IS_INVOICE_NO, # 未开票
            '0' => Invoice::IS_INVOICE_NO, # 未开票
            '1' => Invoice::IS_INVOICE_YES, # 已开票
        ];

        foreach ($originals  as $original){
            $template_detail = [
                'user_id' => $original->userID,
                'issue_type' => $original->userType,
                'type' => $original->invoiceType,
                'head' => $original->title,
                'num' => $original->taxID,
                'bank' => $original->bankName,
                'account' => $original->bankAccount,
                'address' => $original->regAddr,
                'phone' => $original->companyTel,
                'invoice_business_file' => $original->businessLicense,
                'invoice_seniority_file' => $original->taxpayer,
            ];

            $address_detail = [
                'user_id' => $original->userID,
                'address' => $original->contactAddr,
                'contact_name' => $original->contactName,
                'contact_phone' => $original->contactTel,
            ];

            $data[] = [
                'id' => $original->id,
                'user_id' => $original->userID,
                'type' => $types[$original->invoice_content],
                'email' => $original->receive_email ? $original->receive_email : '',
                'value' => $original->money * 100,
                'express_money' => $original->postMoney * 100,
                'service_money' => $original->sx_money * 100,
                'template_detail' => json_encode($template_detail),
                'address_detail' => json_encode($address_detail),
                'current_step_id' => 0,
                'current_audit_id' => 0,
                'is_invoice' => $is_invoices[$original->result],
                'is_finish_audit' => $original->result == 0 ? Invoice::IS_FINISH_AUDIT_NO :Invoice::IS_FINISH_AUDIT_YES,
                'finished_at' => $original->handleTime,
                'created_at' => $original->createTime,
                'updated_at' => $original->createTime,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}