<?php
/**
 * 消息模板数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\MessageTemplate;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;
use Illuminate\Support\Facades\DB;

class MessageTemplates
{
    private static $original_table = 'template'; # 老数据表名
    private static $new_table = 'message_templates'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 老数据的短信标识
        $data = self::dataConversion($connection, $page);
        $originalIdentitys = array_column($data['customers'],NULL,'code');

        $identitys = MessageTemplate::query()
            ->where('type','=','sms')
            ->pluck('identity')
            ->toArray();

        // 新老标识映射
        $identityMap  = [
            'sms_tm_reg_status_change' => 'tm_status_change',
            'sms_tm_reg_status_partback' => 'tm_status_partback',
            'sms_tm_reg_status_back' => 'tm_status_back',
            'sms_tm_reg_status_no' => 'tm_status_no',
            'sms_tm_reg_status_confirm' => 'tm_status_confirm',
            'sms_tm_service_status_change' => 'tms_status_change',
            'sms_tm_international_status_change' => 'tm_international_status',
            'sms_tm_notarization_status_change' => 'tm_notarization',
            'sms_tm_patent_status_change' => 'ipr_status_change',
            'sms_tm_copyright_status_change' => 'ipr_status_change',
            'sms_tm_applicant_status_change_yes' => 'applyer_status_change_yes',
            'sms_tm_applicant_status_change_no' => 'applyer_status_change_no',
            'sms_tm_monitor_status_change' => 'tm_status_change2',
            'sms_tm_trade_status_change' => 'tmjy_status_change',
            'sms_captcha_op_password_reset' => 'validate',
            'sms_domain_expire' => 'domain_renew_remind_1',
            'sms_domain_expired' => 'domain_renew_remind_2',
//            'sms_ssl_expire' => '',
            'sms_server_will_expire' => 'server_renew_remind_1',
            'sms_server_expire' => 'server_renew_remind_2',
            'sms_server_expired' => 'server_renew_remind_3',
            'sms_server_open' => 'server_open',
            'sms_vhost_will_expire' => 'nyhost_renew_remind_1',
            'sms_vhost_expired' => 'nyhost_renew_remind_2',
            'sms_etp_email_will_expire' => 'etpemail_renew_remind1',
            'sms_etp_email_expired' => 'etpemail_renew_remind2',
            'sms_gw_will_expire' => 'gw_renew_remind1',
            'sms_gw_expired' => 'gw_renew_remind2',
            'sms_register' => 'register',
            'sms_getpassword' => 'getpassword',
            'sms_captcha_mobile_modify' => 'modifyMobile',
            'sms_captcha_email_modify' => 'modifyEmail',
            'sms_captcha_admin_login' => 'adminLogin',
        ];

        foreach ($identitys as $identity){
            if(!isset($identityMap[$identity]) || !isset($originalIdentitys[$identityMap[$identity]])){
                continue;
            }
            $updateData = [
                'dh_identity' => $originalIdentitys[$identityMap[$identity]]->smsiddh,
                'ytx_identity' => $originalIdentitys[$identityMap[$identity]]->yunpianid
            ];
            DB::table(self::$new_table)->where('identity','=', $identity)->update($updateData);
        }

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table)->whereIn('type', [1,2]);

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->select(['smsiddh','yunpianid','code'])
            ->get()
            ->toArray();

        return [
            'is_finished' => true,
            'customers' => $originals
        ];
    }
}

