<?php
/**
 * 订单数据迁移（把原有的发票生成一个新的订单）
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\Order;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class Orders
{
    private static $original_table = 'users'; # 老数据表名
    private static $new_table = 'orders'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table)
            ->where('invoice', '>', 0);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        foreach ($originals  as $original){
            $data[] = [
                'order_num' => 'ep_' . createGuid(),
                'user_id' => $original->id,
                'business_type' => Order::BUSINESS_TYPE_STATION_SERVICE,
                'business_id' => 0,
                'transaction_type' => 'invoice',
                'coupon_id' => 0,
                'payable_price' => 0,
                'preferential_price' => 0,
                'paid_price' => 0,
                'status' => Order::STATUS_DELIVERED,
                'paid_at' => date('Y-m-d H:i:s'),
                'invoice_enable' => Order::INVOICE_ENABLE_YES,
                'is_invoiced' => Order::INVOICE_STATUS_PENDING,
                'invoice_amount' => $original->invoice * 100,
                'invoice_id' => 0,
                'refund_status' => Order::STATUS_REFUND_PENDING,
                'created_at' => date('Y-m-d H:i:s'),
                'updated_at' => date('Y-m-d H:i:s'),
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}
