<?php
/**
 * 价格数据迁移
 * User: lzs
 * Date: 2020/11/30
 * Time: 10:20
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Models\Price;
use App\Models\Product;
use App\Models\UserGroup;
use App\Services\Migration\Prices\DomainReg;
use App\Services\Migration\Prices\DomainTrade;
use App\Services\Migration\Prices\EtpEmail;
use App\Services\Migration\Prices\GwWeb;
use App\Services\Migration\Prices\MiniProgram;
use App\Services\Migration\Prices\Server;
use App\Services\Migration\Prices\Ssl;
use App\Services\Migration\Prices\TmIpr;
use App\Services\Migration\Prices\TmTrade;
use App\Services\Migration\Prices\Vhost;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class Prices
{
    private static $priceProducts = [
        'domain' => DomainReg::class,
        'tm' => TmIpr::class,
        'cloud' => Server::class,
        'website' => GwWeb::class,
        'ssl' => Ssl::class,
        'tmjiaoyi' => TmTrade::class,
        'nyhost' => Vhost::class,
        'etpemail' => EtpEmail::class,
        'miniprogram' => MiniProgram::class,
        'domaintrade' => DomainTrade::class,
    ];

    private static $productTypeMap = [
        'domain' => Product::PRODUCT_DOMAIN_REG,
        'tm' => Product::PRODUCT_TM_IPR,
        'cloud' => Product::PRODUCT_SERVER,
        'website' => Product::PRODUCT_GW_WEB,
        'ssl' => Product::PRODUCT_SSL,
        'tmjiaoyi' => Product::PRODUCT_TM_TRADE,
        'nyhost' => Product::PRODUCT_VIRTUAL_HOST,
        'etpemail' => Product::PRODUCT_ETP_EMAIL,
        'miniprogram' => Product::PRODUCT_MINI_PROGRAM,
        'domaintrade' => Product::PRODUCT_DOMAIN_TRADE,
    ];

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 价格数据迁移
        $data = self::prices($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('prices', $data['prices'], $page);

        // 专利版权价格sku单独处理
        self::setSkus('prices');
        self::setSkus('price_costs');

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 专利版权价格sku处理
     * @param $tableName
     * @author ePower JCQ
     * @date 2022/6/6
     */
    public static function setSkus($tableName){
        $productIds = [
            'faming',
            'shiyong',
            'waiguan',
            'zhuanlibohui',
            'meishu',
            'wenzi',
            'ruanjian',
            'qita',
        ];
        $price = \Illuminate\Support\Facades\DB::table($tableName)->whereIn('product_id',$productIds)->get();
        if ($price) {
            \Illuminate\Support\Facades\DB::transaction(function () use ($price, $tableName) {
                foreach ($price as $value) {
                    $skus = [
                        'none' => '0.00'
                    ];
                    $collection = json_decode($value->collection, true);
                    if(!$collection){
                        continue;
                    }

                    if (in_array($value->product_id, ['faming', 'shiyong', 'waiguan', 'zhuanlibohui'])) {
                        foreach ($collection as $k => $val) {
                            $skus[$k] = $val['value'];
                        }
                    }

                    if (in_array($value->product_id, ['qita'])) {
                        if (isset($collection['normal']['value'])) {
                            $skus['default'] = $collection['normal']['value'];
                        }
                    }

                    if (in_array($value->product_id, ['meishu', 'wenzi', 'ruanjian'])) {
                        foreach ($collection['apply'] as $k => $val) {
                            $skus[$k] = $val['value'];
                        }
                    }
                    $data = [
                        'skus' => json_encode($skus),
                        'collection' => '{}',
                    ];
                    \Illuminate\Support\Facades\DB::table($tableName)->where('id', $value->id)->update($data);
                }
            });
        }
    }

    /**
     * 获取价格数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function prices(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('products_prices')->where('user_type', 0);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $fields = ['id', 'user_type', 'user_id', 'price_type', 'type_value', 'price_year_1', 'price_year_2', 'price_year_3', 'price_year_4', 'price_year_5', 'price_year_6', 'price_year_7', 'price_year_8', 'price_year_9', 'price_year_10', 'price_year_renew_1', 'price_year_renew_2', 'price_year_renew_3', 'price_year_renew_4', 'price_year_renew_5', 'price_year_renew_6', 'price_year_renew_7', 'price_year_renew_8', 'price_year_renew_9', 'price_year_renew_10', 'status', 'price_transfer', 'price_restore', 'pdtype', 'pdid'];
        $prices = $baseQuery->select($fields)
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        $time = date('Y-m-d H:i:s');
        $userGroups = UserGroup::query()->pluck('grade')->toArray();
        foreach ($prices  as $price){
            if (!in_array($price->user_id, $userGroups)){
                continue;
            }
            $productType = isset(self::$productTypeMap[$price->pdtype]) ? self::$productTypeMap[$price->pdtype] : '';
            if (!$productType) continue;
            $class = isset(self::$priceProducts[$price->pdtype]) ? self::$priceProducts[$price->pdtype] : null;
            if (!$class) continue;
            $parse = call_user_func([$class, 'parse'], $price, $connection);
            if ($parse === false) continue;

            $data[] = [
                'group_id' => $price->user_id,
                'product_type' => $productType,
                'product_id' => $parse['product_id'],
                'collection' => json_encode($parse['collection']),
                'enable' => $price->status == Price::ENABLE_YES ? Price::ENABLE_YES : Price::ENABLE_NO,
                'created_at' => $time,
                'updated_at' => $time,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'prices' => $data
        ];
    }
}
