<?php
/**
 * 域名注册价格迁移数据解析
 * User: lzs
 * Date: 2020/11/30
 * Time: 10:59
 * Brand: ePower
 */

namespace App\Services\Migration\Prices;


use App\Models\DomainSuffix;
use App\Models\Price;
use Illuminate\Database\ConnectionInterface;

class DomainReg
{
    public static function parse($price, ConnectionInterface $connection)
    {
        // 获取对应产品
        $product = $connection->table('domains_types')->where('type_id', $price->pdid)->first();
        if (!$product){
            return false;
        }
        if (DomainSuffix::query()->where('identity', $product->type_id)->doesntExist()){
            return false;
        }

        // 数据处理
        $transferInPrices = [   # 转入价格
            'value' => bcmul($price->price_transfer, 100, 0),
            'type' => Price::TYPE_FIXED,
        ];
        $redemptionPrices = [   # 赎回价格
            'value' => bcmul($price->price_restore, 100, 0),
            'type' => Price::TYPE_FIXED,
        ];
        $regPrices = [];    # 注册价格
        $renewPrices = [];  # 续费价格
        for ($i = 1; $i <= 10; $i++){
            $regPrices[$i.'_y'] = [
                'value' => bcmul($price->{'price_year_'.$i}, 100, 0),
                'years' => $i,
                'type' => Price::TYPE_FIXED,
            ];
            $renewPrices[$i.'_y'] = [
                'value' => bcmul($price->{'price_year_renew_'.$i}, 100, 0),
                'years' => $i,
                'type' => Price::TYPE_FIXED,
            ];
        }

        $collection = [
            'reg' => $regPrices,
            'renew' => $renewPrices,
            'transfer_in' => $transferInPrices,
            'redemption' => $redemptionPrices,
        ];

        return ['product_id' => $product->type_id, 'collection' => $collection];
    }

}