<?php
/**
 * 小程序价格迁移数据解析
 * User: lzs
 * Date: 2020/11/30
 * Time: 16:22
 * Brand: ePower
 */

namespace App\Services\Migration\Prices;


use App\Models\Price;
use App\Models\XzysProduct;
use Illuminate\Database\ConnectionInterface;

class MiniProgram
{
    public static function parse($price, ConnectionInterface $connection)
    {
        // 获取对应产品
        $product = $connection->table('xzys_products')->where('product_id', $price->pdid)->first();
        if (!$product){
            return false;
        }
        if (XzysProduct::query()->where('identity', $product->product_id)->doesntExist()){
            return false;
        }

        // 数据处理
        $collection = [];
        switch ($product->product_id){
            case '101':
            case '102':
            case '103':
            case '104':
            case '105':
            case '106':
                $buyPrices = [];    # 注册价格
                $renewPrices = [];  # 续费价格
                for ($i = 1; $i <= 10; $i++){
                    $buyPrices[$i.'_y'] = [
                        'value' => bcmul($price->{'price_year_'.$i}, 100, 0),
                        'years' => $i,
                        'type' => Price::TYPE_FIXED,
                    ];
                    $renewPrices[$i.'_y'] = [
                        'value' => bcmul($price->{'price_year_renew_'.$i}, 100, 0),
                        'years' => $i,
                        'type' => Price::TYPE_FIXED,
                    ];
                }
                $collection = [
                    'buy' => $buyPrices,
                    'renew' => $renewPrices,
                ];
                break;
            case '201':
                $collection = [
                    'buy' => [
                        'value' => bcmul($price->price_year_1, 100, 0),
                        'type' => Price::TYPE_UNIT,
                    ],
                    'renew' => [
                        'value' => bcmul($price->price_year_renew_1, 100, 0),
                        'type' => Price::TYPE_UNIT,
                    ],
                ];
                break;
            case '202':
            case '203':
            case '204':
                $collection = [
                    'buy' => [
                        'value' => bcmul($price->price_year_1, 100, 0),
                        'type' => Price::TYPE_UNIT,
                    ],
                ];
                break;
        }

        return ['product_id' => $product->product_id, 'collection' => $collection];
    }
}