<?php
/**
 * SSL 价格迁移数据解析
 * User: lzs
 * Date: 2020/11/30
 * Time: 15:13
 * Brand: ePower
 */

namespace App\Services\Migration\Prices;


use App\Models\Price;
use App\Models\SslProduct;
use Illuminate\Database\ConnectionInterface;

class Ssl
{
    public static function parse($price, ConnectionInterface $connection)
    {
        // 获取对应产品
        $product = $connection->table('ssl_products')->where('product_id', $price->pdid)->first();
        if (!$product){
            return false;
        }
        if (SslProduct::query()->where('identity', $product->product_id)->doesntExist()){
            return false;
        }

        // 数据处理
        if ($product->product_id == 99){
            $collection = [
                'buy' => [
                    'value' => bcmul($price->type_value, 100, 0),
                    'type' => Price::TYPE_FIXED,
                ],
            ];

            return ['product_id' => $product->product_id, 'collection' => $collection];
        }
        $basicPrices = [];
        $extraPrices = [];
        if ($product->max_domains > $product->fixed_domains){
            for ($i = 1; $i <= 1; $i++){
                $basicPrices[$i.'_y'] = [
                    'value' => bcmul($price->{'price_year_'.$i}, 100, 0),
                    'years' => $i,
                    'type' => Price::TYPE_FIXED,
                ];
                $extraPrices[$i.'_y'] = [
                    'value' => bcmul($price->{'price_year_renew_'.$i}, 100, 0),
                    'years' => $i,
                    'type' => Price::TYPE_UNIT,
                ];
            }
        }else{
            for ($i = 1; $i <= 1; $i++){
                $basicPrices[$i.'_y'] = [
                    'value' => bcmul($price->{'price_year_'.$i}, 100, 0),
                    'years' => $i,
                    'type' => Price::TYPE_FIXED,
                ];
            }
        }

        $collection = [
            'basic' => $basicPrices
        ];
        if ($extraPrices) $collection['extra'] = $extraPrices;

        return ['product_id' => $product->product_id, 'collection' => $collection];
    }
}