<?php
/**
 * 商标知产价格迁移数据解析
 * User: lzs
 * Date: 2020/11/30
 * Time: 11:59
 * Brand: ePower
 */

namespace App\Services\Migration\Prices;


use App\Models\Price;
use App\Models\TmProduct;
use Illuminate\Database\ConnectionInterface;

class TmIpr
{
    public static function parse($price, ConnectionInterface $connection)
    {
        // 获取对应产品
        $product = $connection->table('tm_products')->where('id', $price->pdid)->first();
        if (!$product){
            return false;
        }
        if (TmProduct::query()->where('identity', $product->remindinfo)->doesntExist()){
            return false;
        }

        // 数据处理
        $collection = [];
        switch($product->product_type){
            case 'zhuce':
                $collection = [
                    '<=10' => [
                        'value' => bcmul($price->price_year_1, 100, 0),
                        'type' => Price::TYPE_FIXED,
                    ],
                    '>10' => [
                        'value' => bcmul($price->price_year_renew_1, 100, 0),
                        'type' => Price::TYPE_UNIT,
                    ],
                ];
                break;
            case 'patent':
                if ($product->remindinfo == 'zhuanlibohui'){
                    $collection = [
                        'invention' => [
                            'value' => bcmul($price->price_year_1, 100, 0),
                            'type' => Price::TYPE_FIXED,
                        ],
                        'utility_model' => [
                            'value' => bcmul($price->price_year_2, 100, 0),
                            'type' => Price::TYPE_FIXED,
                        ],
                        'industrial_design' => [
                            'value' => bcmul($price->price_year_3, 100, 0),
                            'type' => Price::TYPE_FIXED,
                        ],
                    ];
                    break;
                }
                $collection = [
                    'no_mitigation' => [
                        'value' => bcmul($price->price_year_1, 100, 0),
                        'type' => Price::TYPE_FIXED,
                    ],
                    'personal_mitigation' => [
                        'value' => bcmul($price->price_year_2, 100, 0),
                        'type' => Price::TYPE_FIXED,
                    ],
                    'multiple_mitigation' => [
                        'value' => bcmul($price->price_year_3, 100, 0),
                        'type' => Price::TYPE_FIXED,
                    ],
                ];
                break;
            case 'copyright':
                if ($product->remindinfo == 'qita'){
                    $collection = [
                        'normal' => [
                            'value' => bcmul($price->price_year_1, 100, 0),
                            'type' => Price::TYPE_FIXED,
                        ],
                    ];
                    break;
                }
                $collection = [
                    'apply' => [
                        '31-50_d' => [
                            'value' => bcmul($price->price_year_2, 100, 0),
                            'type' => Price::TYPE_FIXED,
                        ],
                        '26-30_d' => [
                            'value' => bcmul($price->price_year_3, 100, 0),
                            'type' => Price::TYPE_FIXED,
                        ],
                        '21-25_d' => [
                            'value' => bcmul($price->price_year_4, 100, 0),
                            'type' => Price::TYPE_FIXED,
                        ],
                        '16-20_d' => [
                            'value' => bcmul($price->price_year_5, 100, 0),
                            'type' => Price::TYPE_FIXED,
                        ],
                        '11-15_d' => [
                            'value' => bcmul($price->price_year_6, 100, 0),
                            'type' => Price::TYPE_FIXED,
                        ],
                        '6-10_d' => [
                            'value' => bcmul($price->price_year_7, 100, 0),
                            'type' => Price::TYPE_FIXED,
                        ],
                        '5_d' => [
                            'value' => bcmul($price->price_year_8, 100, 0),
                            'type' => Price::TYPE_FIXED,
                        ],
                        '4_d' => [
                            'value' => bcmul($price->price_year_9, 100, 0),
                            'type' => Price::TYPE_FIXED,
                        ],
                        '3_d' => [
                            'value' => bcmul($price->price_year_10, 100, 0),
                            'type' => Price::TYPE_FIXED,
                        ],
                    ],
                ];
                break;
            case 'addservice':
            case 'international':
            case 'notarization':
            case 'service':
            $collection = [
                    'buy' => [
                        'value' => bcmul($price->price_year_1, 100, 0),
                        'type' => Price::TYPE_FIXED,
                    ],
                ];
                break;
        }

        return ['product_id' => $product->remindinfo, 'collection' => $collection];
    }

}