<?php
/**
 * 管理员入款申请数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\Receipt;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class Receipts
{
    private static $original_table = 'change_money'; # 老数据表名
    private static $new_table = 'receipts'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table)->whereIn('status',[1])->whereNotNull('userID');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        $types = [
          'fee' => 'expense',
          'commission' => 'recharge',
          'withdrawal' => 'withdraw',
          'refund' => 'refund',
          'trade' => 'expense',
          'recharge' => 'recharge',
          'order' => 'expense',
          'consume' => 'expense',
        ];

        $workflowId = $connection->table('admin_workflow')
            ->where('code','=','W_recharge')
            ->value('id');

        // 最后一步审核
        $auditResults = $connection->table('admin_workflow_audit')
            ->where('workflowId', '=', $workflowId)
            ->orderBy('id','asc')
            ->pluck('auditResult','instanceId')
            ->toArray();

        foreach ($originals  as $original){
            $data[] = [
                'id' => $original->id,
                'user_id' => $original->userID,
                'admin_id' => 0,
                'type' => isset($types[$original->type]) ? $types[$original->type] : '',
                'value' => $original->money * 100,
                'remarks' => $original->remarks,
                'current_step_id' => 0,
                'current_audit_id' => 0,
                'invoice_amount' => 0,
                'is_receipt' => $auditResults[$original->id] == 1 ? Receipt::IS_RECEIPT_YES : Receipt::IS_RECEIPT_NO,
                'is_finish_audit' => $original->status == 1 ? Receipt::IS_FINISH_AUDIT_YES : Receipt::IS_FINISH_AUDIT_NO,
                'finished_at' => $original->createTime,
                'created_at' => $original->createTime,
                'updated_at' => $original->createTime,
                'receipt_voucher_file' => '',
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}
