<?php
/**
 * 用户充值明细数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class  Recharges
{
    private static $original_table = 'users_recharge'; # 老数据表名
    private static $new_table = 'recharges'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        $types = [
            'alipay' => 'alipay',
            'weixin' => 'wechat',
        ];

        foreach ($originals  as $original){
            $data[] = [
                'id' => $original->id,
                'type' => $types[$original->type],
                'trade_type' => '',
                'user_id' => $original->userID,
                'out_trade_no' => $original->orderNo,
                'transaction_id' => $original->tradeNo,
                'value' => $original->money * 100,
                'status' => $original->status == 1 ? 1 : 0,
                'handler_at' => $original->handleTime,
                'created_at' => $original->createTime,
                'updated_at' => $original->createTime,
                'remark' => $original->remarks ? $original->remarks : '',
                'inner_remark' => '',
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}
