<?php
/**
 * 退款申请数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\Refund;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class Refunds
{
    private static $original_table = 'refund'; # 老数据表名
    private static $new_table = 'refunds'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table)->whereIn('result',[-1,1]);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        $businessTypes = [
          '1' => Refund::BUSINESS_TYPE_SERVER,
          '2' => 'database',
          '3' => Refund::BUSINESS_TYPE_VIRTUAL_HOST,
          '4' => Refund::BUSINESS_TYPE_TM_IPR,
          '5' => Refund::BUSINESS_TYPE_TM_IPR,
          '6' => Refund::BUSINESS_TYPE_DOMAIN_REG,
          '7' => Refund::BUSINESS_TYPE_SSL,
          '8' => Refund::BUSINESS_TYPE_VAS,
          '9' => Refund::BUSINESS_TYPE_TM_IPR,
          '10' => Refund::BUSINESS_TYPE_TM_TRADE,
          '11' => Refund::BUSINESS_TYPE_DOMAIN_REG,
          '12' => Refund::BUSINESS_TYPE_ETP_EMAIL,
          '13' => Refund::BUSINESS_TYPE_CUSTOM_SERVICE,
          '14' => Refund::BUSINESS_TYPE_TM_IPR,
          '15' => Refund::BUSINESS_TYPE_TM_IPR,
        ];

        foreach ($originals  as $original){
            $data[] = [
                'id' => $original->id,
                'business_type' => $businessTypes[$original->serviceType],
                'business_id' => $original->serviceID,
                'transaction_type' => '',
                'user_id' => $original->userID,
                'admin_id' => 0,
                'order_id' => 0,
                'reason' => $original->reasonIndex,
                'remarks' => $original->remarks,
                'value' => $original->money * 100,
                'current_step_id' => 0,
                'current_audit_id' => 0,
                'is_refund' => $original->result == 1 ? 1 : 0,
                'is_finish_audit' => !$original->result ? Refund::IS_FINISH_AUDIT_NO :Refund::IS_FINISH_AUDIT_YES,
                'finished_at' => $original->handleTime,
                'created_at' => $original->createTime,
                'updated_at' => $original->createTime,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}