<?php
/**
 * 云服务器过户数据迁移
 * User: lzs
 * Date: 2020/10/13
 * Time: 10:24
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class ServerPushes
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 云服务器过户数据迁移
        $data = self::pushes($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('server_pushes', $data['pushes'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取云服务器过户数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function pushes(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('servers_push')->where('isDelete', '0')->where('status', '1');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $pushes = $baseQuery->select(['serverId', 'fromUserId', 'toUserId', 'remarks', 'pushTime'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        $time = date('Y-m-d H:i:s');
        foreach ($pushes  as $push){
            $data[] = [
                'admin_id' => 0,
                'server_id' => $push->serverId,
                'from_user_id' => $push->fromUserId,
                'to_user_id' => $push->toUserId,
                'remark' => $push->remarks,
                'created_at' => $push->pushTime,
                'updated_at' => $time,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'pushes' => $data
        ];
    }
}