<?php
/**
 * 云服务器快照数据迁移
 * User: lzs
 * Date: 2020/10/13
 * Time: 10:05
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Models\ServerSnapshot;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class ServerSnapshots
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 云服务器快照数据迁移
        $data = self::snapshots($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('server_snapshots', $data['snapshots'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取云服务器快照数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function snapshots(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('servers_snap_list')->where('status', '<>', '-1');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $snapshots = $baseQuery->select(['status', 'serverId', 'name', 'apiName', 'createTime', 'endTime'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        $time = date('Y-m-d H:i:s');
        foreach ($snapshots  as $snapshot){
            $data[] = [
                'server_id' => $snapshot->serverId,
                'name' => $snapshot->name,
                'ny_name' => $snapshot->apiName,
                'parent_ny_name' => '',
                'is_current' => ServerSnapshot::IS_CURRENT_YES,
                'status' => $snapshot->status,
                'expired_at' => $snapshot->endTime,
                'created_at' => $snapshot->createTime,
                'updated_at' => $time,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'snapshots' => $data
        ];
    }
}