<?php
/**
 * 云服务器数据迁移
 * User: lzs
 * Date: 2020/10/13
 * Time: 9:23
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Models\Server;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class Servers
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 云服务器数据迁移
        $data = self::servers($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('servers', $data['servers'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取云服务器数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function servers(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('servers')->where('orderStatus', '<>', '-2');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $servers = $baseQuery->select(['id', 'userID', 'serverName', 'guid', 'lineID', 'systemID', 'ip', 'localIP', 'cpu', 'memory', 'harddisks', 'bandwidth', 'defense', 'loginName', 'apiLockStatus', 'snapStatus', 'orderStatus', 'runStatus', 'actStatus', 'endTime', 'buyTime'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        $time = date('Y-m-d H:i:s');
        $replaceDate = date('Y-m-d H:i:s', 1);  # 时间戳小于 1 的，都是不正常的时间，用这个时间代替
        foreach ($servers  as $server){
            $data[] = [
                'id' => $server->id,
                'user_id' => $server->userID,
                'name' => $server->serverName ?: '',
                'guid' => $server->guid,
                'line_id' => $server->lineID,
                'system_id' => $server->systemID,
                'ip' => $server->ip,
                'local_ip' => $server->localIP,
                'cpu' => $server->cpu,
                'ram' => $server->memory,
                'hard_disks' => $server->harddisks,
                'bandwidth' => $server->bandwidth,
                'defense' => $server->defense,
                'login_name' => $server->loginName,
                'is_api_locked' => empty($server->apiLockStatus) ? Server::IS_API_LOCKED_NO : Server::IS_API_LOCKED_YES,
                'snapshot_status' => $server->snapStatus ?? 0,
                'order_status' => $server->orderStatus ?? 0,
                'run_status' => $server->runStatus ?? 0,
                'act_status' => $server->actStatus ?? 0,
                'expired_at' => isset($server->endTime) ? (strtotime($server->endTime)<1 ? $replaceDate : $server->endTime) : null,
                'created_at' => isset($server->buyTime) ? (strtotime($server->buyTime)<1 ? $replaceDate : $server->buyTime) : null,
                'updated_at' => $time,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'servers' => $data
        ];
    }
}
