<?php
/**
 * 第三方登录数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class SocialUsers
{
    private static $original_table = 'third_login'; # 老数据表名
    private static $new_table = 'social_users'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table)
            ->whereRaw("user_id IS NOT NULL AND ((login_type = 'qq' AND open_id IS NOT NULL) OR (login_type = 'ticket' AND mp_open_id IS NOT NULL))");

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        foreach ($originals  as $original){
            if($original->login_type == 'qq'){
                $type = 'qq';
                $open_id = $original->open_id;
            }elseif ($original->login_type == 'ticket'){
                $type = 'wechat';
                $open_id = $original->mp_open_id;
            }else{
                continue;
            }

            $data[] = [
                'id' => $original->id,
                'type' => $type,
                'user_id' => $original->user_id,
                'open_id' => $open_id,
                'nickname' => $original->nick_name ? $original->nick_name : '',
                'created_at' => $original->create_time ? date('Y-m-d H:i:s', $original->create_time) : null,
                'updated_at' => $original->update_time ? date('Y-m-d H:i:s', $original->update_time) : null,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}
