<?php
/**
 * ssl证书数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\Ssl;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class Ssls
{
    private static $original_table = 'ssl_orders'; # 老数据表名
    private static $new_table = 'ssls'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);;

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        foreach ($originals  as $original){
            $data[] = [
                'id' => $original->id,
                'user_id' => $original->userid,
                'product_id' => $original->product_id,
                'domains_num' => $original->domains_count,
                'servers_num' => $original->servers_count,
                'years' => $original->years,
                'domains' => $original->domains,
                'company_name' => $original->companyname,
                'company_phone' => $original->companyphone,
                'orgunit' => $original->orgunit,
                'duns' => $original->duns,
                'country' => $original->country,
                'state' => $original->state,
                'city' => $original->city,
                'postcode' => $original->postcode ? $original->postcode : null,
                'address' => $original->addr,
                'adm_fname' => $original->adm_fname,
                'adm_lname' => $original->adm_lname,
                'adm_phone' => $original->adm_phone,
                'adm_email' => $original->adm_email,
                'adm_position' => $original->adm_position,
                'approver_email' => $original->approveremail,
                'registered_at' => $original->start_at,
                'expired_at' => $original->expired_at,
                'status' => $original->status == 7 ? Ssl::expired_status : $original->status,
                'pay_status' => $original->status == 7 ? Ssl::refunded_status : 1,
                'audit_memo' => $original->remarks,
                'add_service' => $original->service ? 99 : 0,
                'unique_id' => $original->orderid,
                'rename' => $original->remarks,
                'created_at' => $original->created_at,
                'updated_at' => $original->created_at,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}

