<?php
/**
 * 商标保姆注册数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\TmAgentReg;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class TmAgentRegs
{
    private static $original_table = 'tm_orders_extends'; # 老数据表名
    private static $new_table = 'tm_agent_regs'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table)
            ->leftJoin('tm_orders','tm_orders.id','=','tm_orders_extends.orderid')
            ->where('producttype', '=', 'zhucebm')
            ->whereNotNull ('name')
            ->whereIn('payed', [0,1,2]);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->select('tm_orders_extends.*','tm_orders.name','tm_orders.cls','tm_orders.payed','tm_orders.status')
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        // 付款状态映射
        $payStatusMaps = [
            '0'=> TmAgentReg::unpaid_status,
            '1'=> TmAgentReg::paid_status,
            '2'=> TmAgentReg::refunded_status,
        ];

        foreach ($originals  as $original){
            if($original->status == '待处理'){
                $original->status = TmAgentReg::unfinished_status; # 待处理
            }else{
                $original->status = TmAgentReg::finished_status; # 已处理
            }

            $data[] = [
                'id' => $original->id,
                'user_id' => $original->userid,
                'name' => $original->name,
                'cls' => $original->cls,
                'num' => $original->num,
                'receive_name' => $original->contactor,
                'receive_phone' => $original->phone,
                'memo' => $original->memo,
                'status' => $original->status,
                'pay_status' => $payStatusMaps[$original->payed],
                'created_at' => $original->createdate,
                'updated_at' => $original->editdate && $original->editdate != '0000-00-00 00:00:00' ? $original->editdate : null,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}


