<?php
/**
 * 商标申请人数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\TmApplicant;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class TmApplicants
{
    private static $original_table = 'tm_applyer'; # 老数据表名
    private static $new_table = 'tm_applicants'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        $statuses = array_flip(TmApplicant::$statuses);
        foreach ($originals  as $original){
            if($original->status == '审核未通过'){
                $original->status = '审核不通过';
            }
            if(!$original->cerificatetype || $original->cerificatetype == -1){
                $original->cerificatetype = 1;
            }

            $data[] = [
                'id' => $original->id,
                'user_id' => $original->userid,
                'type' => $original->type,
                'nationality' => $original->nationality,
                'name' => $original->name,
                'province' => $original->province,
                'city' => $original->city,
                'district' => $original->district,
                'address' => $original->address,
                'certificate_type' => $original->cerificatetype,
                'certificate_code' => $original->cerificatenumber ? $original->cerificatenumber : ($original->credit_code ? $original->credit_code : ''),
                'receive_name' => $original->receivename,
                'receive_phone' => $original->receivephone,
                'receive_postcode' => $original->receivepostcode ? $original->receivepostcode : 0,
                'receive_address_cn' => $original->receiveaddress,
                'status' => $statuses[$original->status],
                'audit_memo' => $original->auditmemo,
                'tm_appplicant_id_front_file' => $original->cerificatefile,
                'tm_appplicant_id_back_file' => $original->cerificatefile2,
                'tm_appplicant_business_file' => $original->businessfile,
                'tm_appplicant_business_en_file' => $original->businessfileen,
                'is_business_file_chinese' => $original->isbusinessfilechinese,
                'name_en' => $original->nameen,
                'address_en' => $original->addressen,
                'unique_id' => $original->remoteid ? $original->remoteid : '',
                'created_at' => $original->addtime,
                'updated_at' => $original->updatetime,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}
