<?php
/**
 * 版权服务数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\TmCopyright;
use App\Models\TmProduct;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class TmCopyrights
{
    private static $original_table = 'ipr_orders'; # 老数据表名
    private static $new_table = 'tm_copyrights'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $types = TmProduct::query()->where('type','copyright')->pluck('identity')->toArray();

        $baseQuery = $connection->table(self::$original_table)
            ->whereIn('product_type', $types)
            ->whereIn('payed', [0,1,2]);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        $product_properties = array_flip([
            '31-50_d' => '3-6个月下证',
            '26-30_d' => '26-30工作日下证',
            '21-25_d' => '21-25工作日下证',
            '16-20_d' => '16-20工作日下证',
            '11-15_d' => '11-15工作日下证',
            '6-10_d' => '6-10工作日下证',
            '5_d' => '5工作日下证',
            '4_d' => '4工作日下证',
            '3_d' => '3工作日下证',
            'normal' => '其他',
        ]);
        $product_properties['31-50工作日下证'] = '31-50_d';
        $product_property = 'normal';

        // 付款状态映射
        $payStatusMaps = [
            '0'=> TmCopyright::unpaid_status,
            '1'=> TmCopyright::paid_status,
            '2'=> TmCopyright::refunded_status,
        ];

        foreach ($originals  as $original){
            $product_name = $original->product_name;

            $new_product_property = $product_property;
            $res = preg_match('/\[(.+)\]/', $product_name, $match);
            if($res){
                $new_product_property = isset($product_properties[$match[1]]) ? $product_properties[$match[1]] : $product_property;
            }

            $data[] = [
                'id'  => $original->id,
                'user_id' => $original->userid,
                'product_type' => $original->product_type,
                'product_property' => $new_product_property,
                'receive_name' => $original->name,
                'receive_phone' => $original->phone,
                'memo' => $original->memo,
                'status' => $original->status,
                'pay_status' => $payStatusMaps[$original->payed],
                'audit_memo' => $original->audit_memo,
                'business_no' => $original->serviceno,
                'unique_id' => $original->orderid ? $original->orderid : '',
                'created_at' => $original->create_at,
                'updated_at' => $original->create_at,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}




