<?php
/**
 * 发文索取数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\TmFileFetch;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class TmFileFetches
{
    private static $original_table = 'tm_files_fetch'; # 老数据表名
    private static $new_table = 'tm_file_fetches'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        foreach ($originals  as $original){
            $address_detail = [
                'id' => 0,
                'user_id' => $original->userid,
                'province' => '',
                'city' => '',
                'district' => '',
                'address' => $original->address,
                'postcode' => $original->zipcode,
                'contact_name' => $original->receiver,
                'contact_phone' => $original->phone,
                'is_default' => 0,
                'last_used_at' => $original->fetchtime,
                'created_at' => $original->fetchtime,
                'updated_at' => $original->fetchtime,
            ];

            $data[] = [
                'id'  => $original->id,
                'user_id' => $original->userid,
                'address_id' => 0,
                'address_detail' => json_encode($address_detail),
                'audit_memo' => $original->memo,
                'express_info' => $original->expressno,
                'expressed_at' => $original->posttime,
                'status' => $original->status,
                'post_type' => $original->is_fawenjifu,
                'to_ep' => $original->guid ? TmFileFetch::is_to_ep : TmFileFetch::is_not_to_ep,
                'unique_id' => $original->guid ? $original->guid : 0,
                'created_at' => $original->fetchtime,
                'updated_at' => $original->fetchtime,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}
