<?php
/**
 * 商标发文数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\TmProduct;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;
use Illuminate\Support\Facades\DB;

class TmFiles
{
    private static $original_table = 'tm_files'; # 老数据表名
    private static $new_table = 'tm_files'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        // 兼容以前的迁移bug
        DB::update("UPDATE ep_tm_files SET type = 1 WHERE((business_type IN ('copyright', 'patent')AND file_type <> '受理通知书')OR (business_type IN ('zhuce', 'service')AND file_type = '商标证书（纸质）')OR (created_at < '2018-12-04 00:00:01'AND file_type = '商标证书'))AND type = 0");

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        $IdentityTypeMaps = TmProduct::query()->pluck('type','identity')->toArray(); # 产品标识和类型映射

        foreach ($originals  as $original){
            if(!isset($IdentityTypeMaps[$original->bisnisstype])){ # 垃圾数据
                continue;
            }

            $business_type = $IdentityTypeMaps[$original->bisnisstype]; # 业务类型

            $data[] = [
                'id'  => $original->id,
                'user_id' => $original->userid,
                'business_type' => $business_type,
                'business_identity' => $original->bisnisstype,
                'business_no' => $original->applyno,
                'type' => $original->type,
                'file_type' => $original->filetype,
                'tm_file' => isset($original->file) ? $original->file : 0,
                'fetch_id' => $original->fetchid,
                'status' => $original->status,
                'to_ep' => $original->createtoep,
                'unique_id' => $original->guid ? $original->guid : 0,
                'created_at' => $original->uploadtime,
                'updated_at' => $original->uploadtime,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}

