<?php
/**
 * 国际商标数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\TmInternational;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class TmInternationals
{
    private static $original_table = 'tm_international_orders'; # 老数据表名
    private static $new_table = 'tm_internationals'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table)
            ->whereIn('payed', [0,1,2]);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        // 付款状态映射
        $payStatusMaps = [
            '0'=> TmInternational::unpaid_status,
            '1'=> TmInternational::paid_status,
            '2'=> TmInternational::refunded_status,
        ];

        foreach ($originals  as $original){
            $data[] = [
                'id' => $original->id,
                'user_id' => $original->userid,
                'product_type' => $original->product_type,
                'receive_name' => $original->name,
                'receive_phone' => $original->phone,
                'memo' => $original->memo,
                'status' => $original->status,
                'pay_status' => $payStatusMaps[$original->payed],
                'audit_memo' => $original->audit_memo,
                'business_no' => $original->serviceno,
                'unique_id' => $original->orderid ? $original->orderid : '',
                'created_at' => $original->create_at,
                'updated_at' => $original->create_at,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}



