<?php
/**
 * 商标监控数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\TmMonitor;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class TmMonitors
{
    private static $original_table = 'tm_monitors'; # 老数据表名
    private static $new_table = 'tm_monitors'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        $statuses = [
            '1' => TmMonitor::unmonitored_status,
            '2' => TmMonitor::monitored_status,
        ];

        foreach ($originals  as $original){
            $data[] = [
                'id'  => $original->id,
                'user_id' => $original->userid,
                'name' => $original->tmname,
                'cls' => $original->tmcls,
                'tm_id' => $original->tmid,
                'tm_status' => $original->tm_status,
                'applicant' => $original->tmapplyer,
                'image' => $original->tmimg,
                'status' => $statuses[$original->status],
                'unique_id' => $original->orderid,
                'created_at' => $original->createdate,
                'updated_at' => $original->editdate,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}


