<?php
/**
 * 商标公证数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\TmNotarization;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class TmNotarizations
{
    private static $original_table = 'notarizations'; # 老数据表名
    private static $new_table = 'tm_notarizations'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table)
            ->whereIn('pay_status', [0,1,3]);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        // 付款状态映射
        $payStatusMaps = [
            '0'=> TmNotarization::unpaid_status,
            '1'=> TmNotarization::paid_status,
            '3'=> TmNotarization::refunded_status,
        ];

        foreach ($originals  as $original){
            $original_assignor_detail = json_decode($original->assignor_detail,true); # 原转让人信息
            // 新老数据转化
            $assignor_detail = [
                'tmn_zr_id_front_file' => $original_assignor_detail['person_portraint_img'],
                'tmn_zr_id_back_file' => $original_assignor_detail['person_emblem_img'],
                'tmn_zr_business_file' => $original_assignor_detail['company_business_license_img'],
                'zr_type' => $original_assignor_detail['type'],
                'zr_person_title' => $original_assignor_detail['person_title'],
                'zr_person_card_no' => $original_assignor_detail['person_card_no'],
                'zr_link_mobile' => $original_assignor_detail['link_mobile'],
                'zr_company_card_no' => $original_assignor_detail['company_card_no'],
                'zr_company_address' => $original_assignor_detail['company_address'],
                'zr_company_title' => $original_assignor_detail['company_title'],
            ];

            $original_assignee_detail = json_decode($original->assignee_detail,true); # 原受让人信息
            // 新老数据转化
            $assignee_detail = [
                'tmn_sr_id_front_file' => $original_assignee_detail['person_portraint_img'],
                'tmn_sr_id_back_file' => $original_assignee_detail['person_emblem_img'],
                'tmn_sr_business_file' => $original_assignee_detail['company_business_license_img'],
                'sr_type' => $original_assignee_detail['type'],
                'sr_person_title' => $original_assignee_detail['person_title'],
                'sr_person_card_no' => $original_assignee_detail['person_card_no'],
                'sr_company_card_no' => $original_assignee_detail['company_card_no'],
                'sr_company_country' => $original_assignee_detail['company_country'],
                'sr_company_title' => $original_assignee_detail['company_title'],
            ];

            $original_paper_address_detail = json_decode($original->paper_address_detail,true); # 原纸质公证书寄送地址
            // 新老数据转化
            $paper_address_detail = [
                'paper_address_name' => $original_paper_address_detail['paper_address_name'],
                'paper_address_mobile' => $original_paper_address_detail['paper_address_mobile'],
                'paper_address_address' => $original_paper_address_detail['paper_address_address'],
            ];

            $data[] = [
                'id' => $original->id,
                'user_id' => $original->user_id,
                'tm_name' => $original->tm_name,
                'tmn_reg_file' => $original->tm_img,
                'tmn_zrzm_file' => $original->tm_zrzm_img,
                'tmn_gdhjy_file' => $original->gdhjy_img,
                'price_type' => $original->tm_price,
                'cls' => $original->cls,
                'cls_name' => $original->cls_name,
                'tm_id' => $original->regno,
                'status' => $original->status,
                'pay_status' => $payStatusMaps[$original->pay_status],
                'gz_sign_qrcode' => $original->gz_sign_qrcode ? $original->gz_sign_qrcode : '',
                'is_send_electron' => $original->is_send_electron,
                'electron_email' => $original->electron_email,
                'is_send_paper' => $original->is_send_paper,
                'paper_num' => $original->paper_num,
                'assignor_detail' => json_encode($assignor_detail),
                'assignee_detail' => json_encode($assignee_detail),
                'paper_address_detail' => json_encode($paper_address_detail),
                'certificate_url' => $original->certificate_uri ? $original->certificate_uri : '',
                'paper_express_title' => $original->paper_express_title ? $original->paper_express_title : '',
                'paper_express_number' => $original->paper_express_number ? $original->paper_express_number : '',
                'audit_memo' => $original->remark,
                'unique_id' => $original->unique_id ? $original->unique_id : '',
                'created_at' => $original->created_at,
                'updated_at' => $original->updated_at,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}
