<?php
/**
 * 专利服务数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\TmPatent;
use App\Models\TmProduct;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class TmPatents
{
    private static $original_table = 'ipr_orders'; # 老数据表名
    private static $new_table = 'tm_patents'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $types = TmProduct::query()->where('type','patent')->pluck('identity')->toArray();

        $baseQuery = $connection->table(self::$original_table)
            ->whereIn('product_type', $types)
            ->whereIn('payed', [0,1,2]);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        $product_properties = array_flip([
            'no_mitigation' => '不减缓申请',
            'personal_mitigation' => '个人减缓申请',
            'multiple_mitigation' => '多人减缓申请',
            'invention' => '发明专利',
            'utility_model' => '实用新型专利',
            'industrial_design' => '外观设计专利',
        ]);
        $product_property = 'normal';

        // 付款状态映射
        $payStatusMaps = [
            '0'=> TmPatent::unpaid_status,
            '1'=> TmPatent::paid_status,
            '2'=> TmPatent::refunded_status,
        ];

        foreach ($originals  as $original){
            $product_name = $original->product_name;

            $res = preg_match('/\[(.+)\]/', $product_name, $match);
            if($res){
                $product_property = isset($product_properties[$match[1]]) ? $product_properties[$match[1]] : $product_property;
            }

            $data[] = [
                'id'  => $original->id,
                'user_id' => $original->userid,
                'product_type' => $original->product_type,
                'product_property' => $product_property,
                'receive_name' => $original->name,
                'receive_phone' => $original->phone,
                'memo' => $original->memo,
                'status' => $original->status,
                'pay_status' => $payStatusMaps[$original->payed],
                'audit_memo' => $original->audit_memo,
                'business_no' => $original->serviceno,
                'unique_id' => $original->orderid ? $original->orderid : '',
                'created_at' => $original->create_at,
                'updated_at' => $original->create_at,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}




