<?php
/**
 * 商标查询需求 数据迁移
 * User: lzs
 * Date: 2020/12/18
 * Time: 10:39
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Models\TmQueryRequirement;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class TmQueryRequirements
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 商标查询需求数据迁移
        $data = self::requirements($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('tm_query_requirements', $data['requirements'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取商标查询需求数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function requirements(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('needs')->where('type', 2);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $requirements = $baseQuery->select(['contact', 'content', 'datetime', 'tel', 'status', 'ip', 'createarea'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        $time = date('Y-m-d H:i:s');
        foreach ($requirements  as $requirement){
            $data[] = [
                'contact' => $requirement->contact ?: '',
                'phone' => $requirement->tel ?: '',
                'keyword' => $requirement->content ?: '',
                'ip' => $requirement->ip ?: '',
                'location' => $requirement->createarea ?: '',
                'is_processed' => $requirement->status == 1 ? TmQueryRequirement::PROCESSED_YES : TmQueryRequirement::PROCESSED_NO,
                'created_at' => $requirement->datetime,
                'updated_at' => $time,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'requirements' => $data
        ];
    }
}