<?php
/**
 * 商标注册数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\TmReg;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class TmRegs
{
    private static $original_table = 'tm_orders'; # 老数据表名
    private static $new_table = 'tm_regs'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table)
            ->whereIn('payed', [0,1,2])
            ->whereNotNull ('goodsnamearray');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 保姆注册对应的id
        $agentIds = $connection->table('tm_orders_extends')
            ->pluck('id','orderid');

        // 处理数据
        $data = [];

        // 付款状态映射
        $payStatusMaps = [
            '0'=> TmReg::unpaid_status,
            '1'=> TmReg::paid_status,
            '2'=> TmReg::refunded_status,
        ];

        foreach ($originals  as $original){
            $data[] = [
                'id' => $original->id,
                'user_id' => $original->userid ? $original->userid : 0,
                'product_type' => $original->producttype,
                'name' => $original->name ? $original->name : '',
                'description' => $original->explanation ? $original->explanation : '',
                'cls' => $original->cls,
                'goodsnamearray' => $original->goodsnamearray ? $original->goodsnamearray : '',
                'applicant_id' => $original->applyerid ? $original->applyerid : 0,
                'status' => $original->status ? $original->status : TmReg::unverified_status,
                'pay_status' => $payStatusMaps[$original->payed],
                'tm_id' => $original->applynumber,
                'audit_memo' => $original->auditmemo,
                'tm_registration_delegation_file' => $original->delegationfile ? $original->delegationfile : '',
                'tm_registration_image_file' => $original->image1file ? $original->image1file : '',
                'tm_fenxibaogao_file' => $original->fenxibaogao ? $original->fenxibaogao : '',
                'agent_id' => isset($agentIds[$original->id]) ? $agentIds[$original->id] : 0,
                'unique_id' => $original->remoteid ? $original->remoteid : '',
                'add_service' => $original->addservice ? $original->addservice : '',

                'created_at' => $original->submittime,
                'updated_at' => $original->updatetime,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}

