<?php
/**
 * 商标服务数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\TmService;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class TmServices
{
    private static $original_table = 'tm_services'; # 老数据表名
    private static $new_table = 'tm_services'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table)
            ->whereIn('payed', [0,1,2]);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        // 付款状态映射
        $payStatusMaps = [
            '0'=> TmService::unpaid_status,
            '1'=> TmService::paid_status,
            '2'=> TmService::refunded_status,
        ];

        foreach ($originals  as $original){
            $data[] = [
                'id'  => $original->id,
                'user_id'  => $original->userid,
                'receive_name'  => $original->name ? $original->name : '',
                'receive_phone'  => $original->contact ? $original->contact : '',
                'memo'  => isset($original->memo) && $original->memo ? $original->memo : '',
                'tm_id'  => $original->number ? $original->number : '',
                'product_type'  => $original->type,
                'status'  => $original->status,
                'pay_status' => $payStatusMaps[$original->payed],
                'audit_memo'  => $original->auditmemo,
                'business_no'  => $original->applyno,
                'unique_id'  => $original->remoteid ? $original->remoteid : '',
                'created_at'  => $original->addtime,
                'updated_at'  => $original->updatetime,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}


