<?php
/**
 * 商标交易持有人数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\TmTradeHolder;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class TmTradeHolders
{
    private static $original_table = 'tmjiaoyiapplyer'; # 老数据表名
    private static $new_table = 'tm_trade_holders'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        $statuses = [
            '0' => TmTradeHolder::unverified_status, # 待审核
            '1' => TmTradeHolder::succeed_status, # 审核通过
            '2' => TmTradeHolder::failed_status, # 审核不通过
        ];

        $adminStatuses = [
            '1' => TmTradeHolder::normal_adminStatus, # 正常
            '2' => TmTradeHolder::lock_adminStatus, # 锁定
        ];
        foreach ($originals  as $original){
            $data[] = [
                'id' => $original->id,
                'user_id' => $original->userid,
                'type' => $original->type,
                'name' => $original->name,
                'receive_name' => $original->contacts,
                'receive_phone' => $original->phone,
                'issued_count' => $original->publishcount,
                'traded_count' => $original->sellcount,
                'status' => $statuses[$original->status],
                'admin_status' => $adminStatuses[$original->adminstatus],
                'tm_trade_holder_file' => $original->img,
                'audit_memo' => $original->auditmemo,

                'created_at' => $original->createtime,
                'updated_at' => $original->edittime,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}

