<?php
/**
 * 商标交易库（云商标和自有商标的总表）数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\TmTradeLib;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class TmTradeLibs
{
    private static $original_table = 'tm_jiaoyi'; # 老数据表名
    private static $new_table = 'tm_trade_libs'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table)->where(function ($baseQuery){
            $baseQuery->orWhere('userid', '<>', 0)
                ->orWhere('status', '<>', 1)
                ->orWhereNotNull('tmNewImg');
        });

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        $adminStatuses = [
            '1' => TmTradeLib::normal_adminStatus, # 正常
            '2' => TmTradeLib::lock_adminStatus, # 锁定
        ];
        foreach ($originals  as $original){

            // 状态
            if($original->status == 1){
                $status =  TmTradeLib::on_status; # 上架
            }else{
                $status = TmTradeLib::down_status; # 下架
            }

            // 交易状态
            if($original->status == 1 || $original->status == 3){
                $trade_status =  TmTradeLib::normal_tradeStatus; # 正常
            }elseif ($original->status == 4){
                $trade_status =  TmTradeLib::trading_tradeStatus; # 交易中
            }elseif($original->status == 2 || $original->status == 5){
                $trade_status =  TmTradeLib::finished_tradeStatus; # 交易完成
            }

            $data[] = [
                'id' => $original->id,
                'user_id' => $original->userid,
                'cls' => $original->cls,
                'cls_name' => $original->clsName ? $original->clsName : '',
                'name' => $original->name ? $original->name : '',
                'tm_id' => $original->tmId ? $original->tmId : '',
                'cls_tm_id' => $original->cls . '_' . $original->tmId,
                'price' => $original->price * 100,
                'similar_group' => $original->productsEn ? $original->productsEn : '',
                'range' => $original->products ? $original->products : '',
                'registered_at' => $original->regDate && $original->regDate != '0000-00-00 00:00:00' ? $original->regDate : null,
                'expired_at' => $original->expiredDate && $original->expiredDate != '0000-00-00 00:00:00' ? $original->expiredDate : null,
                'applicant' => $original->applyerName ? $original->applyerName : '',
                'tm_trade_image' => $original->tmImg ? $original->tmImg : '',
                'tm_trade_custom_image' => $original->tmNewImg,
                'type' => $original->type ? $original->type : TmTradeLib::tupian_type,
                'length' => $original->length,
                'commission' => $original->commission,
                'view' => $original->views,
                'sort_id' => $original->sortId,
                'status' => $status,
                'trade_status' => $trade_status,
                'admin_status' => $adminStatuses[$original->adminstatus],
                'regist_issue_no' => $original->regist_issue_no,
                'regist_issue_date' => $original->regist_issue_date,
                'regist_issue_img' => $original->regist_issue_img,
                'preliminary_issue_no' => $original->preliminary_issue_no,
                'preliminary_issue_date' => $original->preliminary_issue_date,
                'preliminary_issue_img' => $original->preliminary_issue_img,
                'tag' => $original->tag ? $original->tag : '',
                'is_intro' => $original->is_info,
                'intro' => htmlspecialchars_decode($original->info),
                'created_at' => $original->createtime,
                'updated_at' => $original->edittime,

                'sale_price' => $original->sellprice * 100,
                'return_tm' => $original->returntm,
                'last_update_at' => $original->last_update_at && $original->last_update_at != '0000-00-00 00:00:00' ? $original->last_update_at : $original->createtime,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}

