<?php
/**
 * 商标交易业务数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\TmClass;
use App\Models\TmTrade;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class TmTrades
{
    private static $original_table = 'tmjiaoyi_orders'; # 老数据表名
    private static $new_table = 'tm_trades'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table)->whereIn('payed', [1,2,3])->whereNotNull('tmcls');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        // 付款状态映射
        $payStatusMaps = [
            '1'=> TmTrade::paid_deposit_status,
            '2'=> TmTrade::paid_tail_status,
            '3'=> TmTrade::refunded_status,
        ];

        $tmMainClass = TmClass::getMainClass();
        $types = [
            '1' => TmTrade::epower_type, # epower商标
            '2' => TmTrade::local_type, # 自有商标
        ];
        $statuses = array_flip(TmTrade::$statuses);
        foreach ($originals  as $original){
            $local_id = 0;
            if($original->type == 2){
                $publish_id = $connection->table('tm_jiaoyipublish')
                    ->where('cls', $original->tmcls)
                    ->where('tmId', $original->tmid)
                    ->value('id');

                $local_id = $publish_id ? $publish_id : 0;
            }

            $cls = strlen($original->tmcls) == 1 ? '0' . $original->tmcls : $original->tmcls;
            $data[] = [
                'id' => $original->id,
                'user_id' => $original->userid,
                'name' => $original->tmname,
                'tm_id' => $original->tmid,
                'cls' => $original->tmcls,
                'cls_name' => isset($tmMainClass[$cls]) ? $tmMainClass[$cls] : '',
                'tm_trade_image' => $original->tmimg,
                'tm_trade_certificate' => $original->file,
                'tm_price' => $original->tmmoney * 100,
                'deposit_price' => $original->bond * 100,
                'service_price' => $original->servicemoney * 100,
                'receive_name' => $original->name,
                'receive_phone' => $original->phone,
                'memo' => $original->memo,
                'type' => $types[$original->type],
                'local_id' => $local_id,
                'status' => $statuses[$original->status],
                'pay_status' => $payStatusMaps[$original->payed],
                'audit_memo' => $original->auditmemo,
                'return_tm' => $original->returntm,
                'unique_id' => $original->orderid,
                'created_at' => $original->createTime,
                'updated_at' => $original->editTime,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}

