<?php
/**
 * 用户提现账户数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\Area;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class UserAccounts
{
    private static $original_table = 'users_account'; # 老数据表名
    private static $new_table = 'user_accounts'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        // 区域代码
        $areas = Area::query()->pluck('code','name');

        foreach ($originals  as $original){
            $data[] = [
                'id' => $original->id,
                'user_id' => $original->userID,
                'type' => $original->type,
                'account_name' => $original->accountName,
                'account_num' => $original->accountNumb,
                'province' => isset($areas[$original->province]) ? $areas[$original->province] : '',
                'city' => isset($areas[$original->city]) ? $areas[$original->city] : '',
                'district' => isset($areas[$original->area]) ? $areas[$original->area] : '',
                'bank_name' => $original->bankName ? $original->bankName : '',
                'bank_full_name' => $original->bankFullName ? $original->bankFullName : '',
                'deleted_at' => $original->isDelete == 1 ? date('Y-m-d H:i:s') : null,
                'created_at' => $original->createTime,
                'updated_at' => $original->createTime,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}

