<?php
/**
 * 收货常用地址数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\Area;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class UserAddresses
{
    private static $original_table = 'users_address'; # 老数据表名
    private static $new_table = 'user_addresses'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        // 区域代码
        $areas = Area::query()->pluck('code','name');

        foreach ($originals  as $original){
            $data[] = [
                'id' => $original->id,
                'user_id' => $original->userId,
                'province' => isset($areas[$original->province]) ? $areas[$original->province] : '',
                'city' => isset($areas[$original->city]) ? $areas[$original->city] : '',
                'district' => isset($areas[$original->area]) ? $areas[$original->area] : '',
                'address' => $original->details,
                'postcode' => $original->postCode,
                'contact_name' => $original->postName,
                'contact_phone' => $original->postMobile,
                'is_default' => $original->isDefault,
                'created_at' => date('Y-m-d H:i:s'),
                'updated_at' => date('Y-m-d H:i:s'),
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}

