<?php
/**
 * 用户认证数据迁移
 * User: lzs
 * Date: 2020/10/9
 * Time: 9:09
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Models\Attachment;
use App\Models\UserAuth;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class UserAuths
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 会员认证数据迁移
        $data = self::auths($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('user_auths', $data['auths'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取用户认证数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function auths(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('users_auth')
            ->where('isDelete', '0')
            ->where('status', 20);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $auths = $baseQuery->select(['id', 'userId', 'authType', 'authName', 'authNumb', 'authPic1', 'authPic2', 'status', 'returnText', 'handleTime', 'createTime'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        $attachmentPaths = [];
        foreach ($auths as $auth){
            if ($auth->authPic1){
                $attachmentPaths[] = $auth->authPic1;
            }
            if ($auth->authPic2){
                $attachmentPaths[] = $auth->authPic2;
            }
        }

        $attachments = Attachment::query()->whereIn('path', $attachmentPaths)->pluck('id', 'path')->all();

        // 处理数据
        $data = [];
        $time = date('Y-m-d H:i:s');
        foreach ($auths  as $auth){
            if (!in_array($auth->authType, UserAuth::$types)){
                continue;
            }

            $data[] = [
                'id' => $auth->id,
                'user_id' => $auth->userId,
                'type' => $auth->authType,
                'name' => $auth->authName,
                'number' => $auth->authNumb,
                'identity_card_front' => $auth->authType == UserAuth::TYPE_INDIVIDUAL ? (isset($attachments[$auth->authPic1]) ? $attachments[$auth->authPic1] : 0) : 0,
                'identity_card_reverse' => $auth->authType == UserAuth::TYPE_INDIVIDUAL ? (isset($attachments[$auth->authPic2]) ? $attachments[$auth->authPic2] : 0) : 0,
                'license' => $auth->authType == UserAuth::TYPE_ENTERPRISE ? (isset($attachments[$auth->authPic1]) ? $attachments[$auth->authPic1] : 0) : 0,
                'comment' => $auth->returnText,
                'status' => UserAuth::STATUS_AUTH_SUCCESS,
                'submitted_at' => $auth->createTime,
                'audited_at' => $auth->handleTime,
                'created_at' => $auth->createTime,
                'updated_at' => $time,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'auths' => $data
        ];
    }


}