<?php
/**
 * 会员等级数据迁移
 * User: lzs
 * Date: 2020/10/16
 * Time: 9:31
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Models\UserGroup;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class UserGroups
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 会员等级数据迁移
        $data = self::groups($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('user_groups', $data['groups'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取会员等级数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function groups(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('users_grade');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $groups = $baseQuery->select(['id', 'grade_name', 'grade_id', 'once_money_upgrade', 'total_money_upgrade', 'allow_auto_upgrade', 'trademark_limit', 'tm_monitors_limit', 'website_limit', 'status'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        $time = date('Y-m-d H:i:s');
        foreach ($groups  as $group){
            $upgradeCondition = [
                UserGroup::UPGRADE_CONDITION_FIRST_RECHARGE => bcmul($group->once_money_upgrade, 100, 0),
                UserGroup::UPGRADE_CONDITION_TOTAL_RECHARGE => bcmul($group->total_money_upgrade, 100, 0),
            ];
            $data[] = [
                'id' => $group->id,
                'name' => $group->grade_name,
                'grade' => $group->grade_id,
                'upgrade_conditions' => json_encode($upgradeCondition),
                'auto_upgrade' => intval($group->allow_auto_upgrade) === 0 ? 0 : 1,
                'tm_query_times_limit' => intval($group->trademark_limit),
                'tm_monitor_limit' => intval($group->tm_monitors_limit),
                'website_limit' => intval($group->website_limit),
                'enable' => intval($group->status) === 0 ? 0 : 1,
                'created_at' => $time,
                'updated_at' => $time,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'groups' => $data
        ];
    }
}