<?php
/**
 * 用户表数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\User;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class Users
{
    private static $original_table = 'users'; # 老数据表名
    private static $new_table = 'users'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table)->whereNotNull('mobile')->where('mobile','<>', '');

        $staff = \App\Models\CustomerServiceStaff::query()->pluck('name', 'id')->toArray();

        $count = $baseQuery->count();

        $pageLimit = 200;
        $offset = ($page - 1) * $pageLimit;
        $originals = $baseQuery->offset($offset)
            ->limit($pageLimit)
            ->get();

        // 处理数据
        $data = [];

        // 用户关系
        $userRelations = $connection->table('users_promotion')->pluck('promoter_id','userid')->toArray();

        foreach ($originals  as $original){
            // 总佣金
            $totalCommission = $connection->table('users_promotion_log')
                ->where('promoter_id', '=', $original->id)
                ->sum('points');

            // 已提现佣金
            $withdrawedCommission = $connection->table('users_promotion_change')
                ->where('userid', '=', $original->id)
                ->where('status', '=', 1)
                ->sum('usermoney');

            // 可提现佣金
            $withdrawCommission = $totalCommission - $withdrawedCommission;

            $data[] = [
                'id' => $original->id,
                'username' => $original->name ? $original->name : User::generateUsername(),
                'group_id' => $original->groupID,
                'qq' => $original->qq ? $original->qq : '',
                'phone' => $original->mobile,
                'email' => $original->email ? $original->email : '',
                'is_auth' => $original->authType ? 1 : 0,
                'customer_service_staff_id' => isset($staff[$original->customerServiceID]) ? $original->customerServiceID : 0,
                'password' => $original->password . $original->salt,
                'op_password' => '',
                'money' => $original->money * 100,
                'recharge' => $original->recharge * 100,
                'consumption' => $original->consumption * 100,
                'parent_user_id' => isset($userRelations[$original->id]) ? $userRelations[$original->id] : 0,
                'commission' => $withdrawCommission * 100,
                'commissioned' => $withdrawedCommission * 100,
                'phone_verified_at' => $original->validPhone == 1 ? date('Y-m-d H:i:s') : null,
                'email_verified_at' => $original->validEmail == 1 ? date('Y-m-d H:i:s') : null,
                'is_tm_trade_white' => $original->tmjiaoyi_status,
                'is_tm_trade_import' => $original->is_tmjy_excel,
                'wechat_notify_enable' => $original->wx_notify,
                'created_at' => date('Y-m-d H:i:s', $original->regTime),
                'updated_at' => $original->lastLoginTime,
                'created_where' => $original->regIP ? $original->regIP : '',
                'login_at' => $original->lastLoginTime,
                'login_where' => $original->lastLoginIP ? $original->lastLoginIP : '',
                'status' => $original->status == 1 ? User::STATUA_NORMAL : User::STATUA_LOCKED,
                'lock_reason' => '',
                'login_status' => $original->lockStatus == '0' ? User::LOGIN_NORMAL : User::LOGIN_LOCKED,
                'login_error_times' => $original->errorTimes,
                'unlock_at' => $original->lockEndTime,
                'is_md5_pwd' => User::IS_MD5_PWD_YES,
            ];
        }

        $isFinished = false;
        if ($page * $pageLimit >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}

