<?php
/**
 * 云虚拟主机数据迁移
 * User: lzs
 * Date: 2020/10/13
 * Time: 11:21
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class Vhosts
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 云虚拟主机数据迁移
        $data = self::vhosts($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('vhosts', $data['vhosts'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取云虚拟主机数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function vhosts(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('host')->where('runStatus', '<>', '8');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $vhosts = $baseQuery->select(['id', 'guid', 'type', 'guid', 'lineId', 'groupId', 'pId', 'userId', 'name', 'ftpUser', 'indeIp', 'ip', 'defaultDomain', 'space', 'connections', 'flow', 'bandwidth', 'runStatus', 'endTime', 'startTime'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        $time = date('Y-m-d H:i:s');
        foreach ($vhosts  as $vhost){
            $data[] = [
                'id' => $vhost->id,
                'user_id' => $vhost->userId,
                'guid' => $vhost->guid,
                'type' => $vhost->type,
                'package_id' => $vhost->pId,
                'line_id' => $vhost->lineId,
                'group_sign' => $vhost->groupId,
                'name' => $vhost->name ?: '',
                'ftp_name' => $vhost->ftpUser,
                'is_independent_ip' => $vhost->indeIp,
                'ip' => $vhost->ip,
                'default_domain' => $vhost->defaultDomain,
                'space' => $vhost->space,
                'connections' => $vhost->connections,
                'flow' => $vhost->flow,
                'bandwidth' => $vhost->bandwidth,
                'run_status' => $vhost->runStatus,
                'expired_at' => $vhost->endTime,
                'created_at' => $vhost->startTime,
                'updated_at' => $time,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'vhosts' => $data
        ];
    }
}
