<?php
/**
 * 友情链接数据迁移
 * User: lzs
 * Date: 2020/11/26
 * Time: 17:40
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Models\WebsiteLink;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class WebsiteLinks
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 友情链接数据迁移
        $data = self::links($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('website_links', $data['links'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取友情链接数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function links(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('sitelinks');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $links = $baseQuery->select(['name', 'url', 'status', 'sortID'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        $time = date('Y-m-d H:i:s');
        foreach ($links  as $link){
            $data[] = [
                'name' => $link->name,
                'link' => $link->url,
                'target' => '_blank',
                'order' => $link->sortID,
                'enable' => $link->status == 1 ? WebsiteLink::ENABLE_YES : WebsiteLink::ENABLE_NO,
                'created_at' => $time,
                'updated_at' => $time,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'links' => $data
        ];
    }

}