<?php
/**
 * 提现申请数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\Area;
use App\Models\Withdraw;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class Withdraws
{
    private static $original_table = 'withdrawal'; # 老数据表名
    private static $new_table = 'withdraws'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table)->whereIn('status',[1]);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        // 用户账户
        $accounts = $connection->table('users_account')->get()->toArray();
        $accounts = array_column($accounts,NULL,'id');

        // 区域代码
        $areas = Area::query()->pluck('code','name');

        foreach ($originals  as $original){
            $account = isset($accounts[$original->accountId]) ? $accounts[$original->accountId] : 0;
            $data[] = [
                'id' => $original->id,
                'user_id' => $original->userId,
                'type' => isset($account->type) ? $account->type : '',
                'account_name' => isset($account->accountName) ? $account->accountName : '',
                'account_num' => isset($account->accountNumb) ? $account->accountNumb : '',
                'province' => isset($account->province) && isset($areas[$account->province]) && $account->province ? $areas[$account->province] : '',
                'city' => isset($account->city) && isset($areas[$account->city]) && $account->city ? $areas[$account->city] : '',
                'district' => isset($account->area) && isset($areas[$account->area]) && $account->area ? $areas[$account->area] : '',
                'bank_name' => isset($account->bankName) ?  $account->bankName : '',
                'bank_full_name' => isset($account->bankFullName) ? $account->bankFullName : '',
                'value' => $original->money * 100,
                'service_money' => $original->cost * 100,
                'actual_amount' => $original->money * 100 - $original->cost * 100,
                'current_step_id' => 0,
                'current_audit_id' => 0,
                'is_withdraw' => $original->result == 1 ? Withdraw::IS_WITHDRAW_YES : Withdraw::IS_WITHDRAW_NO,
                'is_finish_audit' => $original->status == 1 ? Withdraw::IS_FINISH_AUDIT_YES : Withdraw::IS_FINISH_AUDIT_NO,
                'finished_at' => $original->handleTime,
                'created_at' => $original->createTime,
                'updated_at' => $original->createTime,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}
