<?php
/**
 * 工单回复数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\WorkOrderReply;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class WorkOrderReplies
{
    private static $original_table = 'workorder_reply'; # 老数据表名
    private static $new_table = 'work_order_replies'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        $types = [
            '0' => WorkOrderReply::admin_type,
            '1' => WorkOrderReply::user_type,
            '2' => WorkOrderReply::admin_type,
            '3' => WorkOrderReply::admin_type,
        ];

        foreach ($originals  as $original){
            $data[] = [
                'id' => $original->id,
                'work_order_id' => $original->workorderID,
                'type' => $types[$original->type],
                'user_id' => $original->userID,
                'user_name' => $original->userName,
                'content' => $original->content,
                'work_order_file' => $original->attachments,
                'deleted_at' => null,
                'created_at' => date('Y-m-d H:i:s',$original->dateTime),
                'updated_at' => date('Y-m-d H:i:s',$original->dateTime),
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}


