<?php
/**
 * 工单数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\WorkOrder;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class WorkOrders
{
    private static $original_table = 'workorder'; # 老数据表名
    private static $new_table = 'work_orders'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        $statuses = [
            '0' => WorkOrder::received_status,
            '1' => WorkOrder::received_status,
            '2' => WorkOrder::finished_status,
            '3' => WorkOrder::finished_status,
        ];

        #0待分配|1在解决|2新提问|3已回复|4已完成'
        $handleStatuses = [
            '0' => WorkOrder::is_reply_no,
            '1' => WorkOrder::is_reply_no,
            '2' => WorkOrder::is_reply_no,
            '3' => WorkOrder::is_reply_yes,
            '4' => WorkOrder::is_reply_yes,
        ];

        $closeStatuses = [
            '0' => WorkOrder::is_close_no,
            '1' => WorkOrder::is_close_yes,
            '2' => WorkOrder::is_close_yes,
            '3' => WorkOrder::is_close_yes,
        ];

        foreach ($originals  as $original){
            $data[] = [
                'id' => $original->id,
                'user_id' => $original->userID,
                'title' => $original->title,
                'content' => $original->content,
                'work_order_file' => $original->attachments,
                'mobile' => $original->mobile,
                'qq' => $original->qq,
                'status' => $statuses[$original->status],
                'handle_status' => $handleStatuses[$original->handleStatus],
                'close_status' => $closeStatuses[$original->closeStatus],
                'score' => $original->score,
                'evaluation' => $original->evaluation,
                'priority' => $original->priority,
                'created_at' => date('Y-m-d H:i:s',$original->createTime) > '1980-00-00 00:00:00' ? date('Y-m-d H:i:s',$original->createTime) : null,
                'updated_at' =>date('Y-m-d H:i:s',$original->finishTime) > '1980-00-00 00:00:00' ? date('Y-m-d H:i:s',$original->finishTime) : null,
                'submit_at' => date('Y-m-d H:i:s',$original->createTime) > '1980-00-00 00:00:00' ? date('Y-m-d H:i:s',$original->createTime) : null,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}


