<?php
/**
 * 工作流程步骤数据迁移
 * User: jcq
 * Date: 2020/9/27
 * Time: 18:00
 * Brand: ePower
 */

namespace App\Services\Migration;

use App\Models\WorkflowStepAudit;
use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class WorkflowSteps
{
    private static $original_table = 'admin_workflow_step'; # 老数据表名
    private static $new_table = 'workflow_steps'; # 新数据表名

    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 数据转换
        $data = self::dataConversion($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert(self::$new_table, $data['data'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 数据转换
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @author ePower JCQ
     * @date 2020/10/9
     */
    private static function dataConversion(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table(self::$original_table);

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $originals = $baseQuery->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];

        // 原来的审核
        $originalWorkflows = $connection->table('admin_workflow')->pluck('code','id')->toArray();

        // 新老转换
        $originalNewWorkflowMaps = [
            'refund' => WorkflowStepAudit::WORKFLOW_REFUND, # 退款
            'contract' => 'contract', # 合同
            'withdrawal' => WorkflowStepAudit::WORKFLOW_WITHDRAW, # 提现
            'W_fapiao' => WorkflowStepAudit::WORKFLOW_INVOICE, # 发票
            'W_recharge' => WorkflowStepAudit::WORKFLOW_RECHARGE, # 入款
        ];

        $newWorkflows = [];
        foreach ($originalWorkflows as $originalWorkflowKey => &$originalWorkflow){
            if(isset($originalNewWorkflowMaps[$originalWorkflow])){
                $newWorkflows[$originalWorkflowKey] = $originalNewWorkflowMaps[$originalWorkflow];
            }else{
                $newWorkflows[$originalWorkflowKey] = $originalWorkflow;
            }
        }

        foreach ($originals  as $original){
            $data[] = [
                'id' => $original->id,
                'workflow' => $newWorkflows[$original->workflowId],
                'name' => $original->name,
                'description' => $original->description,
                'step' => $original->stepLevel,
                'created_at' => date('Y-m-d H:i:s', $original->createTime),
                'updated_at' => date('Y-m-d H:i:s', $original->createTime),
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'data' => $data
        ];
    }
}

