<?php
/**
 * 小程序账号数据迁移
 * User: lzs
 * Date: 2020/10/13
 * Time: 15:19
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class XzysAccounts
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 小程序账号数据迁移
        $data = self::accounts($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('xzys_accounts', $data['accounts'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取小程序账号数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function accounts(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('xzys_account');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $accounts = $baseQuery->select(['id', 'user_id', 'group_id', 'phone', 'api_account_id', 'account_token', 'type', 'permissions', 'status', 'expire_at', 'created_at'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        $time = date('Y-m-d H:i:s');
        $replaceDate = date('Y-m-d H:i:s', 1);  # 时间戳小于 1 的，都是不正常的时间，用这个时间代替
        foreach ($accounts  as $account){
            $data[] = [
                'id' => $account->id,
                'user_id' => $account->user_id,
                'package_id' => $account->group_id,
                'phone' => $account->phone,
                'unique_id' => $account->api_account_id,
                'token' => $account->account_token,
                'type' => $account->type,
                'status' => $account->status,
                'expired_at' => isset($account->expire_at) ? (strtotime($account->expire_at)<1 ? $replaceDate : $account->expire_at) : null,
                'created_at' => isset($account->created_at) ? (strtotime($account->created_at)<1 ? $replaceDate : $account->created_at) : null,
                'updated_at' => $time,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'accounts' => $data
        ];
    }
}
