<?php
/**
 * 小程序店铺权限数据迁移
 * User: lzs
 * Date: 2020/10/13
 * Time: 16:20
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class XzysStorePermissions
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 小程序店铺权限数据迁移
        $data = self::permissions($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('xzys_store_permissions', $data['permissions'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取小程序店铺权限数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function permissions(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('xzys_stores_permissions');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $permissions = $baseQuery->select(['store_id', 'permission_id', 'expire_at'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        foreach ($permissions  as $permission){
            $data[] = [
                'store_id' => $permission->store_id,
                'permission_id' => $permission->permission_id,
                'expired_at' => $permission->expire_at,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'permissions' => $data
        ];
    }
}