<?php
/**
 * 小程序店铺数据迁移
 * User: lzs
 * Date: 2020/10/13
 * Time: 15:27
 * Brand: ePower
 */

namespace App\Services\Migration;


use App\Services\MigrationService;
use Illuminate\Database\ConnectionInterface;

class XzysStores
{
    public static function handle(ConnectionInterface $connection, $page = 1)
    {
        // 小程序店铺数据迁移
        $data = self::stores($connection, $page);

        // 生成 SQL 语句
        MigrationService::insert('xzys_stores', $data['stores'], $page);

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    /**
     * 获取小程序店铺数据
     * @param ConnectionInterface $connection
     * @param $page
     * @return array
     * @brand ePower
     * @author lzs
     */
    private static function stores(ConnectionInterface $connection, $page)
    {
        $baseQuery = $connection->table('xzys_stores');

        $count = $baseQuery->count();

        $offset = ($page - 1) * MigrationService::PAGE_LIMIT;
        $stores = $baseQuery->select(['id', 'api_store_id', 'account_id', 'name', 'sms_remaining', 'pic_storage_total', 'pic_storage_used', 'status', 'status', 'created_at'])
            ->offset($offset)
            ->limit(MigrationService::PAGE_LIMIT)
            ->get();

        // 处理数据
        $data = [];
        $time = date('Y-m-d H:i:s');
        foreach ($stores  as $store){
            $data[] = [
                'id' => $store->id,
                'name' => $store->name,
                'account_id' => $store->account_id,
                'unique_id' => $store->api_store_id,
                'sms_remaining' => $store->sms_remaining,
                'pic_storage_total' => $store->pic_storage_total,
                'pic_storage_used' => $store->pic_storage_used,
                'status' => $store->status,
                'created_at' => $store->created_at,
                'updated_at' => $time,
            ];
        }

        $isFinished = false;
        if ($page * MigrationService::PAGE_LIMIT >= $count){
            $isFinished = true;
        }

        return [
            'is_finished' => $isFinished,
            'stores' => $data
        ];
    }
}