<?php
/**
 * 数据迁移相关
 * User: lzs
 * Date: 2020/9/27
 * Time: 16:21
 * Brand: ePower
 */

namespace App\Services;


use App\Models\Attachment;
use App\Models\DomainSuffix;
use App\Models\DtProduct;
use App\Models\GwProduct;
use App\Models\Navigation;
use App\Models\Product;
use App\Models\ServerLine;
use App\Models\SslProduct;
use App\Models\TmProduct;
use App\Models\TmtProduct;
use App\Models\VhostPackage;
use App\Models\XwEmailProduct;
use App\Models\XzysProduct;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Cache;
use Illuminate\Support\Facades\Config;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Str;

class MigrationService
{
    const DB_CONFIG = 'migration_db_connection_configs';
    const PAGE_LIMIT = 1000;    # 分页每页的数量
    private $migration_file = '';
    private $db;

    public static $migrations = [
        'attachments',
        'banners',
        'user_auths',
        'user_groups',
        'domain_trades',
        'domain_trade_records',
        'gw_websites',
        'gw_website_domains',
        'gw_icp_codes',
        'gw_website_pushes',
        'gw_examples',
        'gw_agent_constructions',
        'tm_trade_holders',
        'tm_trade_libs',
        'tm_trade_local_libs',
        'tm_trades',
        'tm_applicants',
        'tm_agent_regs',
        'tm_regs',
        'tm_services',
        'tm_patents',
        'tm_copyrights',
        'tm_internationals',
        'tm_files',
        'tm_file_fetches',
        'tm_notarizations',
        'tm_monitors',
        'servers',
        'server_snapshots',
        'server_pushes',
        'vhosts',
        'vhost_pushes',
        'xzys_accounts',
        'xzys_stores',
        'xzys_store_permissions',
        'etp_emails',
        'etp_email_customers',
        'domain_templates',
        'domain_regs',
        'domain_transfer_ins',
        'domain_transfer_outs',
        'domain_pushes',
        'ssls',
        'ssl_files',
        'cs_product_classes',
        'cs_products',
        'custom_services',
        'user_bills',
        'social_users',
        'wechat_menus',
        'wechat_auto_replies',
        'wechat_auto_reply_keywords',
        'wechat_subscribe_replies',
        'commission_products',
        'commission_bills',
        'invoice_templates',
        'invoices',
        'workflow_steps',
        'workflow_step_users',
        'workflow_step_audits',
        'user_addresses',
        'user_accounts',
        'refunds',
        'recharges',
        'receipts',
        'withdraws',
        'tm_reg_status_logs',
        'user_login_logs',
        'user_operation_logs',
        'admin_login_logs',
        'admin_operation_logs',
        'customer_service_staff',
        'users',
        'admin_users',
        'navigations',
        'website_links',
        'article_categories',
        'articles',
        'message_templates',
        'project_requirements',
        'tm_purchase_requirements',
        'tm_query_requirements',
        'configs',
        'prices',
        'orders',
        'work_orders',
        'work_order_replies',
    ];

    public function __construct()
    {
        $this->migration_file = storage_path('migration' . DIRECTORY_SEPARATOR . 'migration.sql');
    }

    /**
     * 数据库初始化
     * @param Request $request
     * @return array
     * @throws \Exception
     * @brand ePower
     * @author lzs
     */
    public function init(Request $request)
    {
        $orms = [
            Product::PRODUCT_TM_IPR => TmProduct::class,
            Product::PRODUCT_TM_TRADE => TmtProduct::class,
            Product::PRODUCT_GW_WEB => GwProduct::class,
            Product::PRODUCT_MINI_PROGRAM => XzysProduct::class,
            Product::PRODUCT_ETP_EMAIL => XwEmailProduct::class,
            Product::PRODUCT_DOMAIN_REG => DomainSuffix::class,
            Product::PRODUCT_DOMAIN_TRADE => DtProduct::class,
            Product::PRODUCT_SSL => SslProduct::class,
            Product::PRODUCT_SERVER => ServerLine::class,
            Product::PRODUCT_VIRTUAL_HOST => VhostPackage::class,
        ];
        foreach ($orms as $orm){
            if (!(new $orm())->existence()){
                throw new \Exception('请先同步产品再进行数据迁移', 422);
            }
        }

        $host = $request->input('host');
        $port = $request->input('port');
        $database = $request->input('database');
        $username = $request->input('username');
        $password = $request->input('password');

        $config = [
            'host' => $host,
            'port' => $port,
            'database' => $database,
            'username' => $username,
            'password' => $password,
        ];
        $this->initDbConfig($config);

        try{
            DB::connection('migration')->select('show tables');
        }catch (\Exception $exception){
            throw new \Exception('数据库连接失败：'.$exception->getMessage(), 400);
        }

        Cache::put(self::DB_CONFIG, [
            'host' => $host,
            'port' => $port,
            'database' => $database,
            'username' => $username,
            'password' => $password,
        ], 3600);
        $dir = dirname($this->migration_file);
        if(!is_dir($dir)){
            mkdir($dir, 0777, true);
        }
        @unlink($this->migration_file);
        return self::$migrations;
    }

    /**
     * 生成迁移数据
     * @param Request $request
     * @return array
     * @brand ePower
     * @author lzs
     */
    public function migrate(Request $request)
    {
        // 数据库连接
        $dbConfig = Cache::get(self::DB_CONFIG);
        $this->initDbConfig($dbConfig);
        $this->db = DB::connection('migration');

        // 构建迁移 SQL 语句
        $type = ucfirst(Str::camel($request->input('type')));
        $page = $request->input('page', 1);
        $data = call_user_func(['App\Services\Migration\\'.$type, 'handle'], $this->db, $page);

        // 保存 SQL 语句
        /*if ($data['sql']){
            $sql = $data['sql'].PHP_EOL;
            file_put_contents($this->migration_file, $sql, FILE_APPEND);
        }*/

        // TODO:如果全部业务处理完了，就删除数据库连接信息

        return [
            'is_finished' => $data['is_finished'],
        ];
    }

    public function getMigrationFile(){
        return $this->migration_file;
    }

    /**
     * 拼接插入 SQL 语句
     * @param string $table
     * @param array $data
     * @param $page
     * @return string
     * @brand ePower
     * @author lzs
     */
    public static function insertSql(string $table, array $data, $page)
    {
        if (empty($data)){
            return '';
        }
        if (! is_array(reset($data))) {
            $data = [$data];
        }

        $fields = array_keys($data[0]);
        $fields = array_map(function ($field){
            return '`'.$field.'`';
        }, $fields);
        $fields = rtrim(implode(', ', $fields));
        if ($page == 1){
            $sql = 'TRUNCATE `' . ENV('DB_PREFIX') . $table.'`;'.PHP_EOL;
        }else{
            $sql = '';
        }
        $sql .= 'INSERT INTO `' . ENV('DB_PREFIX') . $table.'`  ('.$fields.') VALUES ';

        $subSql = '';
        foreach ($data as $datum){
            $tempSql = '(';
            $datum = array_map(function ($value){
                if ($value === null){
                    return 'NULL';
                }
                return '\''.$value.'\'';
            }, $datum);
            $tempSql .= rtrim(implode(', ', $datum)).'),';
            $subSql .= $tempSql;
        }
        $sql .= rtrim($subSql, ',').';'.PHP_EOL;

        return $sql;
    }

    /**
     * 插入迁移数据
     * @param string $table
     * @param array $data
     * @param $page
     * @brand ePower
     * @author lzs
     */
    public static function insert(string $table, array $data, $page)
    {
        if($table == 'customer_service_staff' && !$data){
            return;
        }
        if ($table == 'attachments'){
            DB::table($table)->where('disk', Attachment::DISK_MIGRATION)->delete();
        }
        if ($table == 'navigations'){
            DB::table($table)->where('type', Navigation::TYPE_TOP)->delete();
        }
        if (!in_array($table, ['attachments', 'navigations', 'users_null']) && $page == 1){
            DB::table($table)->truncate();
        }

        DB::table($table)->insert($data);
    }


    /**
     * 初始化数据库连接信息
     * @param $data
     * @brand ePower
     * @author lzs
     */
    private function initDbConfig($data)
    {
        $config = Config::get('database.connections.migration');
        $config['host'] = $data['host'];
        $config['port'] = $data['port'];
        $config['database'] = $data['database'];
        $config['username'] = $data['username'];
        $config['password'] = $data['password'];
        Config::set("database.connections.migration", $config);
    }

}
